@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -44,11 +44,19 @@ void MenuController::showMenu(QPoint pos)
     m_menu->popup(pos);
 }
 
+#if (QT_VERSION_MAJOR == 5)
 void MenuController::enterEvent(QEvent *e)
 {
     Q_UNUSED(e);
     qApp->setOverrideCursor(Qt::ArrowCursor);
 }
+#elif (QT_VERSION_MAJOR == 6)
+void MenuController::enterEvent(QEnterEvent *e)
+{
+    Q_UNUSED(e);
+    qApp->setOverrideCursor(Qt::ArrowCursor);
+}
+#endif
 
 MenuController::~MenuController()
 {
