@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -32,6 +32,7 @@ public:
     }
     ~ToolButton() {}
 protected:
+#if (QT_VERSION_MAJOR == 5)
     void enterEvent(QEvent *e) override
     {
         if (this->isEnabled() && m_hasHoverState) {
@@ -39,6 +40,15 @@ protected:
         }
         DPushButton::enterEvent(e);
     }
+#elif (QT_VERSION_MAJOR == 6)
+    void enterEvent(QEnterEvent *e) override
+    {
+        if (this->isEnabled() && m_hasHoverState) {
+            setFlat(false);
+        }
+        DPushButton::enterEvent(e);
+    }
+#endif
 
     void leaveEvent(QEvent *e) override
     {
