@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -25,26 +25,59 @@
 #include <dlfcn.h>
 #include <signal.h>
 
-const int RecordProcess::RECORD_TYPE_GIF = 0;
-const int RecordProcess::RECORD_TYPE_MP4 = 1;
-const int RecordProcess::RECORD_TYPE_MKV = 2;
-
 const int RecordProcess::RECORD_MOUSE_NULL = 0;
 const int RecordProcess::RECORD_MOUSE_CURSE = 1;
 const int RecordProcess::RECORD_MOUSE_CHECK = 2;
 const int RecordProcess::RECORD_MOUSE_CURSE_CHECK = 3;
 
-const int RecordProcess::RECORD_AUDIO_NULL = 0;
-const int RecordProcess::RECORD_AUDIO_MIC = 1;
-const int RecordProcess::RECORD_AUDIO_SYSTEMAUDIO = 2;
-const int RecordProcess::RECORD_AUDIO_MIC_SYSTEMAUDIO = 3;
-
 const int RecordProcess::RECORD_FRAMERATE_5 = 5;
 const int RecordProcess::RECORD_FRAMERATE_10 = 10;
 const int RecordProcess::RECORD_FRAMERATE_20 = 20;
 const int RecordProcess::RECORD_FRAMERATE_24 = 24;
 const int RecordProcess::RECORD_FRAMERATE_30 = 30;
 
+// 用于任务栏图标DBus通信调用的函数
+const QString DBUS_FUNC_ON_START = "onStart";
+const QString DBUS_FUNC_ON_STOP = "onStop";
+const QString DBUS_FUNC_ON_RECORDING = "onRecording";
+const QString DBUS_FUNC_ON_PAUSE = "onPause";
+
+/**
+   @brief 调用托盘图标"录制中"的对应函数，改变显示状态
+ */
+static QDBusMessage callTrayTimeIcon(const QString &function)
+{
+    QDBusInterface timeInterface("com.deepin.ScreenRecorder.time",
+                                 "/com/deepin/ScreenRecorder/time",
+                                 "com.deepin.ScreenRecorder.time",
+                                 QDBusConnection::sessionBus());
+    return timeInterface.call(function);
+}
+
+/**
+   @brief 调用托盘图标"截图"的对应函数，改变显示状态
+ */
+static QDBusMessage callTrayShotIcon(const QString &function)
+{
+    QDBusInterface shotInterface("com.deepin.ShotRecorder.PanelStatus",
+                                 "/com/deepin/ShotRecorder/PanelStatus",
+                                 "com.deepin.ShotRecorder.PanelStatus",
+                                 QDBusConnection::sessionBus());
+    return shotInterface.call(function);
+}
+
+/**
+   @brief 调用托盘图标"录屏"的对应函数，改变显示状态
+ */
+static QDBusMessage callTrayRecorderIcon(const QString &function)
+{
+    QDBusInterface recorderInterface("com.deepin.ShotRecorder.Recorder.PanelStatus",
+                                     "/com/deepin/ShotRecorder/Recorder/PanelStatus",
+                                     "com.deepin.ShotRecorder.Recorder.PanelStatus",
+                                     QDBusConnection::sessionBus());
+    return recorderInterface.call(function);
+}
+
 RecordProcess::RecordProcess(QObject *parent) : QObject(parent)
 {
     qDebug() << "录屏控制类初始化！";
@@ -92,33 +125,91 @@ void RecordProcess::setRecordInfo(const QRect &recordRect, const QString &filena
 //开始将mp4视频转码成gif
 void RecordProcess::onStartTranscode()
 {
-    qDebug() << __LINE__ << __func__ ;
-    QProcess *transcodeProcess = new QProcess(this);
-    connect(transcodeProcess, QOverload<QProcess::ProcessError>::of(&QProcess::error),
-    [ = ](QProcess::ProcessError processError) {
-        qDebug() << "processError: " << processError;
-    });
-    connect(transcodeProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
-    [ = ](int exitCode, QProcess::ExitStatus exitStatus) {
-        qDebug() << "exitCode: " << exitCode << "  exitStatus: " << exitStatus;
-        //转换进程是否正常退出
-        if (exitStatus == QProcess::ExitStatus::NormalExit) {
-            onTranscodeFinish();
-        } else {
-            qDebug() << "m_pTranscodeProcess is CrashExit:!" ;
+    qInfo() << __LINE__ << __func__ << "正在转码视频(mp4 to gif)...";
+
+    qDebug() << "try to convert palette first";
+    QString captureTempDir = saveTempDir;
+    QString captureSavePath = savePath;
+
+    QThreadPool::globalInstance()->start([ = ](){
+        QString cachePalette = captureTempDir + QDir::separator() + "deepin_screen_recorder_palette.png";
+        QProcess paletteProcess;
+        paletteProcess.start("ffmpeg", {"-i", captureSavePath, "-vf", "select=not(mod(n\\,30)),palettegen=stats_mode=diff", cachePalette, "-y"});
+        qDebug() << paletteProcess.program() << paletteProcess.arguments().join(' ');
+
+        if (!paletteProcess.waitForFinished(10 * 60 * 1000)) {
+            qWarning() << "convert palette failed! " << paletteProcess.errorString();
+            cachePalette.clear();
         }
+
+        QMetaObject::invokeMethod(this, [ = ](){
+            onTranscodePaletteFinished(cachePalette);
+        }, Qt::QueuedConnection);
     });
-    //connect(m_pTranscodeProcess, SIGNAL(finished(int)), this, SLOT(onTranscodeFinish()));
-    //connect(m_pTranscodeProcess, SIGNAL(finished(int)), m_pTranscodeProcess, SLOT(deleteLater()));
+}
+
+void RecordProcess::onTranscodePaletteFinished(const QString &palettePng)
+{
+    QProcess *transcodeProcess = new QProcess(this);
+
+#if (QT_VERSION_MAJOR == 5)
+    connect(transcodeProcess, QOverload<QProcess::ProcessError>::of(&QProcess::error),
+            [ = ](QProcess::ProcessError processError) {
+                qDebug() << "processError: " << processError;
+            });
+#elif (QT_VERSION_MAJOR == 6)
+    // Qt6 syntax for error signal
+    connect(transcodeProcess, &QProcess::errorOccurred,
+            [ = ](QProcess::ProcessError processError) {
+                qDebug() << "processError: " << processError;
+            });
+#endif
+
+#if (QT_VERSION_MAJOR == 5)
+    // Qt6 syntax for finished signal
+    connect(transcodeProcess, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
+            [ = ](int exitCode, QProcess::ExitStatus exitStatus) {
+                qDebug() << "exitCode: " << exitCode << "  exitStatus: " << exitStatus;
+                //转换进程是否正常退出
+                if (exitStatus == QProcess::ExitStatus::NormalExit) {
+                    onTranscodeFinish();
+                } else {
+                    qDebug() << "transcodeProcess is CrashExit:!";
+                }
+            });
+#elif (QT_VERSION_MAJOR == 6)
+    // Qt6 syntax for finished signal
+    connect(transcodeProcess, &QProcess::finished,
+            [ = ](int exitCode, QProcess::ExitStatus exitStatus) {
+                qDebug() << "exitCode: " << exitCode << "  exitStatus: " << exitStatus;
+                //转换进程是否正常退出
+                if (exitStatus == QProcess::ExitStatus::NormalExit) {
+                    onTranscodeFinish();
+                } else {
+                    qDebug() << "transcodeProcess is CrashExit:!";
+                }
+            });
+#endif
+
     QString path = savePath;
     QStringList arg;
     arg << "-i";
     arg << savePath;
+
+    if (!palettePng.isEmpty()) {
+        arg << "-i";
+        arg << palettePng;
+        arg << "-filter_complex";
+        arg << "fps=12,paletteuse=dither=none:diff_mode=rectangle";
+    }
+
     arg << "-r";
     arg << "12";
     arg << path.replace("mp4", "gif");
     transcodeProcess->start("ffmpeg", arg);
-    //部分hw arm架构的机型需要这样设置
+    qDebug() << transcodeProcess->program() << transcodeProcess->arguments().join(' ');
+
+//部分hw arm架构的机型需要这样设置
 #if defined (__aarch64__)
     if (Utils::isWaylandMode) {
         qDebug() << "watting transcode gif end!";
@@ -130,7 +221,7 @@ void RecordProcess::onStartTranscode()
 //转码完成后通知栏弹出提示
 void RecordProcess::onTranscodeFinish()
 {
-    qDebug() << __LINE__ << __func__ ;
+    qInfo() << __LINE__ << __func__ << "已完成转码";
     QString path = savePath;
     QString gifOldPath = path.replace("mp4", "gif");
     QString gifNewPath = QDir(saveDir).filePath(saveBaseName).replace(QString("mp4"), QString("gif"));
@@ -157,6 +248,7 @@ void RecordProcess::onRecordFinish()
 
     // Move file to save directory.
     QString newSavePath = QDir(saveDir).filePath(saveBaseName);
+    QFile::remove(newSavePath);
     QFile::rename(savePath, newSavePath);
     exitRecord(newSavePath);
 }
@@ -173,17 +265,13 @@ void RecordProcess::recordVideo()
     if (t_currentAudioChannel == "-1") {
         qWarning() << "current system audio channel error!";
         //系统音频通道获取错误时，要么不录制声音，要么只录制麦克风音频
-        if (m_audioType == RECORD_AUDIO_SYSTEMAUDIO) {
-            m_audioType = RECORD_AUDIO_NULL;
+        if (m_audioType == Utils::kSystemAudio) {
+            m_audioType = Utils::kNoAudio;
             qWarning() << "选择录制的音频发生改变，录制系统音 变更为 不录系统音！";
-        } else if (m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
-            m_audioType = RECORD_AUDIO_MIC;
+        } else if (m_audioType == Utils::kMicAndSystemAudio) {
+            m_audioType = Utils::kMic;
             qWarning() << "选择录制的音频发生改变，录制混音 变更为 只录制麦克风！";
         }
-    }else {
-        if (t_currentAudioChannel.size() > 1) {
-            t_currentAudioChannel = t_currentAudioChannel.left(t_currentAudioChannel.size() - 1);
-        }
     }
     qDebug() << "current system audio channel:" << t_currentAudioChannel;
     QStringList arguments;
@@ -216,7 +304,7 @@ void RecordProcess::recordVideo()
     arguments << QString("128");
     arguments << QString("-i");
     arguments << QString("%1+%2,%3").arg(displayNumber).arg(m_recordRect.x()).arg(m_recordRect.y()); // 录制区域左上角坐标
-    if (m_audioType == RECORD_AUDIO_SYSTEMAUDIO || m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
+    if (m_audioType == Utils::kSystemAudio || m_audioType == Utils::kMicAndSystemAudio) {
         arguments << QString("-thread_queue_size");
         arguments << QString("2048");
         arguments << QString("-fragment_size");
@@ -230,7 +318,7 @@ void RecordProcess::recordVideo()
         arguments << QString("-i"); // 系统音频id
         arguments << QString("%1").arg(t_currentAudioChannel);
     }
-    if (m_audioType == RECORD_AUDIO_MIC || m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
+    if (m_audioType == Utils::kMic || m_audioType == Utils::kMicAndSystemAudio) {
         arguments << QString("-thread_queue_size");
         arguments << QString("2048");
         arguments << QString("-fragment_size");
@@ -244,7 +332,7 @@ void RecordProcess::recordVideo()
         arguments << QString("-i"); // 麦克风音频id，值为固定"default"
         arguments << QString("default");
     }
-    if (m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
+    if (m_audioType == Utils::kMicAndSystemAudio) {
         arguments << QString("-filter_complex");
         arguments << QString("amerge");
     }
@@ -267,7 +355,7 @@ void RecordProcess::recordVideo()
     arguments << QString("ultrafast");
     arguments << QString("-vsync");
     arguments << QString("passthrough");
-    if (m_recordType == RECORD_TYPE_MKV) {
+    if (m_recordType == Utils::kMKV) {
         arguments << QString("-f");
         arguments << QString("matroska"); // mkv视频
     } else {
@@ -277,6 +365,41 @@ void RecordProcess::recordVideo()
     arguments << QString("-vf");
     arguments << QString("scale=trunc(iw/2)*2:trunc(ih/2)*2");
 #else
+
+    if (m_audioType == Utils::kSystemAudio || m_audioType == Utils::kMicAndSystemAudio) {
+        qDebug() << "x11 ffmpeg 是否录制系统声音？true";
+        arguments << QString("-thread_queue_size");
+        arguments << QString("2048");
+        arguments << QString("-fragment_size");
+        arguments << QString("4096");
+        arguments << QString("-f");
+        arguments << QString("pulse");
+        arguments << QString("-ac");
+        arguments << QString("2");
+        arguments << QString("-ar");
+        arguments << QString("44100");
+        arguments << QString("-i");
+        arguments << QString("%1").arg(t_currentAudioChannel);
+    }
+    if (m_audioType == Utils::kMic || m_audioType == Utils::kMicAndSystemAudio) {
+        qDebug() << "x11 ffmpeg 是否录制麦克风？true";
+        arguments << QString("-thread_queue_size");
+        arguments << QString("2048");
+        arguments << QString("-fragment_size");
+        arguments << QString("4096");
+        arguments << QString("-f");
+        arguments << QString("pulse");
+        arguments << QString("-ac");
+        arguments << QString("2");
+        arguments << QString("-ar");
+        arguments << QString("44100");
+        arguments << QString("-i");
+        arguments << QString("default");
+    }
+
+    // Audio settings need to be in front of.
+    // Otherwise, audio/video desynchronisation may occur during recording.
+    // Link: https://github.com/linuxdeepin/deepin-screen-recorder/pull/256
     arguments << QString("-video_size");
     arguments << QString("%1x%2").arg(m_recordRect.width()).arg(m_recordRect.height());
     if (m_mouseType == RECORD_MOUSE_NULL || m_mouseType == RECORD_MOUSE_CHECK) {
@@ -294,57 +417,31 @@ void RecordProcess::recordVideo()
     arguments << QString("x11grab");
     arguments << QString("-i");
     arguments << QString("%1+%2,%3").arg(displayNumber).arg(m_recordRect.x()).arg(m_recordRect.y());
-
-
-    if (m_audioType == RECORD_AUDIO_SYSTEMAUDIO || m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
-        qDebug() << "x11 ffmpeg 是否录制系统声音？true";
-        arguments << QString("-thread_queue_size");
-        arguments << QString("32");
-        arguments << QString("-fragment_size");
-        arguments << QString("4096");
-        arguments << QString("-f");
-        arguments << QString("pulse");
-        arguments << QString("-ac");
-        arguments << QString("2");
-        arguments << QString("-ar");
-        arguments << QString("44100");
-        arguments << QString("-i");
-        arguments << QString("%1").arg(t_currentAudioChannel);
-        if (m_audioType == RECORD_AUDIO_SYSTEMAUDIO) {
+    
+    //v25 arm上面参数需要放在最后
+    if (m_audioType == Utils::kSystemAudio || m_audioType == Utils::kMicAndSystemAudio) {
+        if (m_audioType == Utils::kSystemAudio) {
             if ((arch.startsWith("ARM", Qt::CaseInsensitive))) {
                 arguments << QString("-af");
                 arguments << QString("volume=20dB");
             }
         }
     }
-    if (m_audioType == RECORD_AUDIO_MIC || m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
-        qDebug() << "x11 ffmpeg 是否录制麦克风？true";
-        arguments << QString("-thread_queue_size");
-        arguments << QString("32");
-        arguments << QString("-fragment_size");
-        arguments << QString("4096");
-        arguments << QString("-f");
-        arguments << QString("pulse");
-        arguments << QString("-ac");
-        arguments << QString("2");
-        arguments << QString("-ar");
-        arguments << QString("44100");
-        arguments << QString("-i");
-        arguments << QString("default");
-    }
-    if (m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
+
+    if (m_audioType == Utils::kMicAndSystemAudio) {
         qDebug() << "x11 ffmpeg 是否录制混音？true";
         arguments << QString("-filter_complex");
         if ((arch.startsWith("ARM", Qt::CaseInsensitive))) {
-            arguments << QString("[1:a]volume=30dB[a1];[a1][2:a]amix=inputs=2:duration=first:dropout_transition=0[out]");
+            arguments << QString("[0:a]volume=30dB[a1];[a1][1:a]amix=inputs=2:duration=first:dropout_transition=0[out]");
             arguments << QString("-map");
-            arguments << QString("0:v");
+            arguments << QString("2:v");
             arguments << QString("-map");
             arguments << QString("[out]");
         } else {
             arguments << QString("amerge");
         }
     }
+
     arguments << QString("-c:v");
     arguments << QString("libx264");
     arguments << QString("-pix_fmt");
@@ -352,7 +449,7 @@ void RecordProcess::recordVideo()
     // baseline 算法，录制的视频在windos自带播放器不能播放
     //arguments << QString("-profile:v");
     //arguments << QString("baseline");
-    if (m_recordType == RECORD_TYPE_MKV) {
+    if (m_recordType == Utils::kMKV) {
         arguments << QString("-qp");
         arguments << QString("23");
     } else {
@@ -383,13 +480,21 @@ void RecordProcess::initProcess()
     // Build temp save path.
     QString date = QDateTime::currentDateTime().toString("yyyyMMddhhmmss");
     QString fileExtension = "mp4";
-    if (m_recordType == RECORD_TYPE_MKV) {
+    if (m_recordType == Utils::kMKV) {
         fileExtension = "mkv";
     }
-    saveBaseName = QString("%1_%2_%3.%4").arg(tr("Record")).arg(saveAreaName).arg(date).arg(fileExtension);
+    if(saveAreaName.isEmpty()){
+        saveBaseName = QString("%1_%2.%3").arg(tr("Record")).arg(date).arg(fileExtension);
+    }else{
+        if(m_isFullScreenRecord){
+            saveBaseName = QString("%1.%2").arg(saveAreaName).arg(fileExtension);
+        }else {
+            saveBaseName = QString("%1_%2_%3.%4").arg(tr("Record")).arg(saveAreaName).arg(date).arg(fileExtension);
+        }
+    }
     savePath = QDir(saveTempDir).filePath(saveBaseName);
-    QFile file(savePath);
-    file.remove();
+    // Remove same cache file first.
+    QFile::remove(savePath);
 }
 void RecordProcess::getScreenRecordSavePath()
 {
@@ -413,8 +518,8 @@ void RecordProcess::getScreenRecordSavePath()
             break;
         }
     }
-    if ((!QDir(saveDir).exists() && QDir().mkdir(saveDir) == false) ||  // 文件不存在，且创建失败
-            (QDir(saveDir).exists() && !QFileInfo(saveDir).isWritable())) {  // 文件存在，且不能写
+    if ((!QDir(saveDir).exists() && QDir().mkdir(saveDir) == false) ||   // 文件不存在，且创建失败
+            (QDir(saveDir).exists() && !QFileInfo(saveDir).isWritable())) {   // 文件存在，且不能写
         saveDir = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first();
     }
     qInfo() << "录屏保存目录: " << saveDir;
@@ -489,29 +594,36 @@ void RecordProcess::GstStartRecord()
     m_gstRecordX->setInputDeviceName(audioUtils->getDefaultDeviceName(AudioUtils::DefaultAudioType::Source));
     m_gstRecordX->setOutputDeviceName(audioUtils->getDefaultDeviceName(AudioUtils::DefaultAudioType::Sink));
     //这里才会设置究竟采集哪些音频设备的音频数据
-    if (m_audioType == RECORD_AUDIO_MIC_SYSTEMAUDIO) {
+    if (m_audioType == Utils::kMicAndSystemAudio) {
         audioType =  GstRecordX::AudioType::Mix;
-    } else if (m_audioType == RECORD_AUDIO_MIC) {
+    } else if (m_audioType == Utils::kMic) {
         audioType =  GstRecordX::AudioType::Mic;
-    } else if (m_audioType == RECORD_AUDIO_SYSTEMAUDIO) {
+    } else if (m_audioType == Utils::kSystemAudio) {
         audioType =  GstRecordX::AudioType::Sys;
     }
     m_gstRecordX->setAudioType(audioType);
     QDateTime date = QDateTime::currentDateTime();
     QString fileExtension = "webm";
-    if (m_recordType == RECORD_TYPE_MKV) {
+    if (m_recordType == Utils::kMKV) {
         videoType =  GstRecordX::VideoType::ogg;
         fileExtension = "ogg";
     } else {
         videoType =  GstRecordX::VideoType::webm;
         fileExtension = "webm";
     }
+    if(saveAreaName.isEmpty()){
+        saveBaseName = QString("%1_%2.%3").arg(tr("Record")).arg(date.toString("yyyyMMddhhmmss")).arg(fileExtension);
+    }else{
+        if(m_isFullScreenRecord){
+            saveBaseName = QString("%1.%2").arg(saveAreaName).arg(fileExtension);
+        }else {
+            saveBaseName = QString("%1_%2_%3.%4").arg(tr("Record")).arg(saveAreaName).arg(date.toString("yyyyMMddhhmmss")).arg(fileExtension);
+        }
+    }
 
-    saveBaseName = QString("%1_%2_%3.%4").arg(tr("Record")).arg(saveAreaName).arg(date.toString("yyyyMMddhhmmss")).arg(fileExtension);
     savePath = QDir(saveTempDir).filePath(saveBaseName);
     // Remove same cache file first.
-    QFile file(savePath);
-    file.remove();
+    QFile::remove(savePath);
     m_gstRecordX->setVidoeType(videoType);
     m_gstRecordX->setSavePath(savePath);
     m_gstRecordX->setX11RecordMouse(m_mouseType);
@@ -555,6 +667,7 @@ void RecordProcess::GstStopRecord()
 void RecordProcess::onExitGstRecord()
 {
     QString newSavePath = QDir(saveDir).filePath(saveBaseName);
+    QFile::remove(newSavePath);
     QFile::rename(savePath, newSavePath);
     //注销gstreamer相关库加载
     gstInterface::unloadFunctions();
@@ -567,8 +680,8 @@ void RecordProcess::startRecord()
 {
     getScreenRecordSavePath();
     //使用QtConcurrent::run受cpu核心线程数的影响，线程池默认大小为CPU核心线程数大小，由于程序中通过此方法启动的线程数超出4个，故再次设置线程池大小
-    QThreadPool::globalInstance()->setMaxThreadCount(QThreadPool::globalInstance()->maxThreadCount() > 6 ? QThreadPool::globalInstance()->maxThreadCount() : 8);
-    //x11下的录屏
+    QThreadPool::globalInstance()->setMaxThreadCount(QThreadPool::globalInstance()->maxThreadCount() > 6 ? QThreadPool::globalInstance()->maxThreadCount() : 10);
+
     if (!Utils::isFFmpegEnv) {
         GstStartRecord();
     } else {
@@ -585,7 +698,7 @@ void RecordProcess::startRecord()
     QJsonObject obj{
         {"tid", EventLogUtils::StartRecording},
         {"version", QCoreApplication::applicationVersion()},
-        {"type", m_recordType == RECORD_TYPE_GIF ? "gif" : (m_recordType == RECORD_TYPE_MKV ? "mkv" : "mp4")}
+        {"type", m_recordType == Utils::kGIF ? "gif" : (m_recordType == Utils::kMKV ? "mkv" : "mp4")}
     };
     EventLogUtils::get().writeLogs(obj);
     if (Utils::isSysHighVersion1040() == false) {
@@ -593,17 +706,16 @@ void RecordProcess::startRecord()
         return;
     }
     //1040及以上的版本可通过此方式启动状态栏图标闪烁
-    QDBusMessage message = QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ScreenRecorder.time",
-                                                                                             "/com/deepin/ScreenRecorder/time",
-                                                                                             "com.deepin.ScreenRecorder.time",
-                                                                                             "onStart"));
-    QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ShotRecorder.PanelStatus",
-                                                                      "/com/deepin/ShotRecorder/PanelStatus",
-                                                                      "com.deepin.ShotRecorder.PanelStatus",
-                                                                      "onStart"));
-    qDebug() << "Start the screen recording timer!";
+    qDebug() << "通知录屏插件开始录屏! currentTime: " << QTime::currentTime();
+    QDBusMessage message = callTrayTimeIcon(DBUS_FUNC_ON_START);
+    callTrayShotIcon(DBUS_FUNC_ON_START);
+    callTrayRecorderIcon(DBUS_FUNC_ON_START);
+
+    qDebug() << "已通知录屏插件开始录屏! currentTime: " << QTime::currentTime();
     m_recordingFlag = true;
-    QtConcurrent::run(this, &RecordProcess::emitRecording);
+    QtConcurrent::run([this]() {
+        this->emitRecording();
+    });
     if (QDBusMessage::ReplyMessage == message.type()) {
         if (!message.arguments().takeFirst().toBool())
             qDebug() << "dde dock screen-recorder-plugin did not receive start message!";
@@ -613,45 +725,50 @@ void RecordProcess::emitRecording()
 {
     while (m_recordingFlag) {
         //qDebug() << "录屏正在进行中! currentTime: " << QTime::currentTime();
-        QDBusMessage message = QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ScreenRecorder.time",
-                                                                                                 "/com/deepin/ScreenRecorder/time",
-                                                                                                 "com.deepin.ScreenRecorder.time",
-                                                                                                 "onRecording"));
-        QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ShotRecorder.PanelStatus",
-                                                                          "/com/deepin/ShotRecorder/PanelStatus",
-                                                                          "com.deepin.ShotRecorder.PanelStatus",
-                                                                          "onRecording"));
+
+        callTrayTimeIcon(DBUS_FUNC_ON_RECORDING);
+        callTrayShotIcon(DBUS_FUNC_ON_RECORDING);
+        callTrayRecorderIcon(DBUS_FUNC_ON_RECORDING);
 
         QThread::msleep(1000);
     }
 }
+
+void RecordProcess::setFullScreenRecord(bool flag)
+{
+    m_isFullScreenRecord = flag;
+}
+
 void RecordProcess::stopRecord()
 {
 //    QJsonObject obj{
 //        {"tid", EventLogUtils::EndRecording},
 //        {"version", QCoreApplication::applicationVersion()},
-//        {"type", m_recordType == RECORD_TYPE_GIF ? "gif" : (m_recordType == RECORD_TYPE_MKV ? "mkv" : "mp4")}
+//        {"type", m_recordType == Utils::kGIF ? "gif" : (m_recordType == Utils::kMKV ? "mkv" : "mp4")}
 //    };
 //    EventLogUtils::get().writeLogs(obj);
     if (Utils::isSysHighVersion1040() == true) {
+        qInfo() << __FUNCTION__ << __LINE__ << "正在暂停录屏计时...";
         qDebug() << "Pause the screen recording timer!";
 
         //系统托盘图标停止闪烁，时间暂停，但还没有结束
-        QDBusMessage message = QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ScreenRecorder.time",
-                                                                                                 "/com/deepin/ScreenRecorder/time",
-                                                                                                 "com.deepin.ScreenRecorder.time",
-                                                                                                 "onPause"));
+        QDBusMessage message = callTrayTimeIcon(DBUS_FUNC_ON_PAUSE);
+
         if (QDBusMessage::ReplyMessage == message.type()) {
             if (!message.arguments().takeFirst().toBool())
                 qDebug() << "dde dock screen-recorder-plugin did not receive stop message!";
         }
+        callTrayShotIcon(DBUS_FUNC_ON_PAUSE);
+        callTrayRecorderIcon(DBUS_FUNC_ON_PAUSE);
+
+        qInfo() << __FUNCTION__ << __LINE__ << "录屏计时已暂停";
     }
     if (Utils::isFFmpegEnv) {
         //停止wayland录屏
         if (Utils::isWaylandMode) {
 #ifdef KF5_WAYLAND_FLAGE_ON
             WaylandIntegration::stopStreaming();
-            if (RECORD_TYPE_GIF == m_recordType) {
+            if (Utils::kGIF == m_recordType) {
                 onStartTranscode();
             } else {
                 onRecordFinish();
@@ -661,7 +778,7 @@ void RecordProcess::stopRecord()
         //停止x11录屏
         else {
             //录制的视频类型是否是gif格式，是gif的话需要进行转码
-            if (RECORD_TYPE_GIF == m_recordType) {
+            if (Utils::kGIF == m_recordType) {
                 connect(m_recorderProcess, SIGNAL(finished(int)), this, SLOT(onStartTranscode()));
             } else {
                 connect(m_recorderProcess, SIGNAL(finished(int)), this, SLOT(onRecordFinish()));
@@ -676,7 +793,8 @@ void RecordProcess::stopRecord()
 //退出录屏（先停止，再弹提示，最后退出）
 void RecordProcess::exitRecord(QString newSavePath)
 {
-    if (!Utils::isRootUser) {
+    if (!Utils::isRootUser && !m_isFullScreenRecord) {
+        qInfo() << __LINE__ << __func__ << "正在弹出保存完成的通知...";
         // Popup notify.
         QDBusInterface notification("org.freedesktop.Notifications",
                                     "/org/freedesktop/Notifications",
@@ -704,8 +822,9 @@ void RecordProcess::exitRecord(QString newSavePath)
             << hints                                                 // hints
             << timeout;                                              // timeout
         notification.callWithArgumentList(QDBus::AutoDetect, "Notify", arg);
+        qInfo() << __LINE__ << __func__ << "已弹出通知消息";
     }
-    if (m_recordType == RECORD_TYPE_GIF) {
+    if (m_recordType == Utils::kGIF) {
         QFile::remove(savePath);
     }
     if (Utils::isWaylandMode) {
@@ -716,16 +835,13 @@ void RecordProcess::exitRecord(QString newSavePath)
 
     m_recordingFlag = false;
     if (Utils::isSysHighVersion1040() == true) {
+        qInfo() << __LINE__ << __func__ << "正在退出录屏计时图标...";
         qDebug() << __LINE__ << ": Stop the screen recording timer!";
         //系统托盘图标结束并退出
-        QDBusMessage message = QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ScreenRecorder.time",
-                                                                                                 "/com/deepin/ScreenRecorder/time",
-                                                                                                 "com.deepin.ScreenRecorder.time",
-                                                                                                 "onStop"));
-        QDBusConnection::sessionBus().call(QDBusMessage::createMethodCall("com.deepin.ShotRecorder.PanelStatus",
-                                                                          "/com/deepin/ShotRecorder/PanelStatus",
-                                                                          "com.deepin.ShotRecorder.PanelStatus",
-                                                                          "onStop"));
+        callTrayTimeIcon(DBUS_FUNC_ON_STOP);
+        callTrayShotIcon(DBUS_FUNC_ON_STOP);
+        callTrayRecorderIcon(DBUS_FUNC_ON_STOP);
+        qInfo() << __LINE__ << __func__ << "录屏计时图标已退出";
     }
 
     //保存到剪切板
