@@ -1,12 +1,13 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "camerawatcher.h"
 
 #include <QThread>
-#include <QCameraInfo>
+#include <QMediaDevices>
+#include <QCameraDevice>
 #include <QDebug>
 
 CameraWatcher::CameraWatcher(QObject *parent)
@@ -42,13 +43,12 @@ void CameraWatcher::setCoulduseValue(bool value)
 void CameraWatcher::slotCameraWatcher()
 {
     bool couldUse = false;
-    //qDebug() << "QCameraInfo::availableCameras()" << QCameraInfo::defaultCamera().deviceName();
-    if (QCameraInfo::availableCameras().count() > 0) {
+    const QList<QCameraDevice> cameras = QMediaDevices::videoInputs();
+    if (!cameras.isEmpty()) {
         couldUse = true;
     }
 
     if (couldUse != m_coulduse) {
-        //发送log信息到UI
         m_coulduse = couldUse;
         emit sigCameraState(couldUse);
     }
