@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -372,12 +372,16 @@ int CAVInputStream::readMicAudioPacket()
             if (ret == AVERROR_EOF) {
                 setbRunThread(false);
             } else {
+                avlibInterface::m_av_packet_unref(&inputPacket);
+                avlibInterface::m_av_frame_free(&inputFrame);
                 continue;
             }
         }
         //AVPacket -> AVFrame
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pMicAudioFormatContext->streams[m_micAudioindex]->codec, inputFrame, &got_frame_ptr, &inputPacket)) < 0) {
             printf("Could not decode audio frame\n");
+            avlibInterface::m_av_packet_unref(&inputPacket);
+            avlibInterface::m_av_frame_free(&inputFrame);
             return ret;
         }
         avlibInterface::m_av_packet_unref(&inputPacket);
@@ -420,12 +424,16 @@ int CAVInputStream::readMicToMixAudioPacket()
             if (ret == AVERROR_EOF) {
                 setbRunThread(false);
             } else {
+                avlibInterface::m_av_packet_unref(&inputPacket);
+                avlibInterface::m_av_frame_free(&inputFrame);
                 continue;
             }
         }
         //AVPacket -> AVFrame
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pMicAudioFormatContext->streams[m_micAudioindex]->codec, inputFrame, &got_frame_ptr, &inputPacket)) < 0) {
             printf("Could not decode audio frame\n");
+            avlibInterface::m_av_packet_unref(&inputPacket);
+            avlibInterface::m_av_frame_free(&inputFrame);
             return ret;
         }
         avlibInterface::m_av_packet_unref(&inputPacket);
@@ -484,11 +492,15 @@ int CAVInputStream::readSysAudioPacket()
             if (ret == AVERROR_EOF) {
                 setbRunThread(false);
             } else {
+                avlibInterface::m_av_packet_unref(&inputPacket);
+                avlibInterface::m_av_frame_free(&input_frame);
                 continue;
             }
         }
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec, input_frame, &got_frame_ptr, &inputPacket)) < 0) {
             printf("Could not decode audio frame\n");
+            avlibInterface::m_av_packet_unref(&inputPacket);
+            avlibInterface::m_av_frame_free(&input_frame);
             return ret;
         }
         avlibInterface::m_av_packet_unref(&inputPacket);
@@ -528,11 +540,15 @@ int CAVInputStream::readSysToMixAudioPacket()
             if (ret == AVERROR_EOF) {
                 setbRunThread(false);
             } else {
+                avlibInterface::m_av_packet_unref(&inputPacket);
+                avlibInterface::m_av_frame_free(&inputFrame);
                 continue;
             }
         }
         if ((ret = avlibInterface::m_avcodec_decode_audio4(m_pSysAudioFormatContext->streams[m_sysAudioindex]->codec, inputFrame, &got_frame_ptr, &inputPacket)) < 0) {
             printf("Could not decode audio frame\n");
+            avlibInterface::m_av_packet_unref(&inputPacket);
+            avlibInterface::m_av_frame_free(&inputFrame);
             return ret;
         }
         avlibInterface::m_av_packet_unref(&inputPacket);
@@ -587,16 +603,26 @@ bool  CAVInputStream::GetAudioSCardInputInfo(AVSampleFormat &sample_fmt, int &sa
 
 QString CAVInputStream::currentAudioChannel()
 {
-    QStringList options;
-    options << QString(QStringLiteral("-c"));
-    options << QString(QStringLiteral("pacmd list-sources | grep -PB 1 'analog.*monitor>' | head -n 1 | perl -pe 's/.* //g'"));
+    QString command = QString("pacmd list-sources");
     QProcess process;
-    process.start(QString(QStringLiteral("bash")), options);
+    process.start(command);
     process.waitForFinished();
     process.waitForReadyRead();
-    QByteArray tempArray =  process.readAllStandardOutput();
-    char *charTemp = tempArray.data();
-    QString str_output = QString(QLatin1String(charTemp));
+    QString str_output = process.readAllStandardOutput();
+
+    QStringList lines = str_output.split("\n");
+    QString targetLine;
+    for (int i = 0; i < lines.size(); i++) {
+        if (lines[i].contains("analog") && lines[i].contains("monitor")) {
+            targetLine = lines[i];
+            break;
+        }
+    }
+
+    if (!targetLine.isEmpty()) {
+        targetLine.remove(QRegExp(".* "));
+    }
+
     process.close();
-    return str_output;
+    return targetLine;
 }
