@@ -1,5 +1,5 @@
 // Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -24,7 +24,7 @@ SaveButton::SaveButton(DWidget *parent)
     m_listBtn->setFixedSize(LIST_BTN);
 
     QHBoxLayout *saveLayout = new QHBoxLayout();
-    saveLayout->setMargin(0);
+    saveLayout->setContentsMargins(0, 0, 0, 0);
     saveLayout->setSpacing(0);
     saveLayout->addWidget(m_saveBtn);
     saveLayout->addWidget(m_listBtn);
