@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -73,7 +73,7 @@ ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
     }
 
     QHBoxLayout *hLayout = new QHBoxLayout();
-    hLayout->setMargin(0);
+    hLayout->setContentsMargins(0, 0, 0, 0);
     hLayout->setSpacing(0);
     hLayout->addWidget(m_subTool, 0, Qt::AlignCenter);
     hLayout->addSpacing(10);
@@ -83,9 +83,13 @@ ToolBarWidget::ToolBarWidget(MainWindow *pMainwindow, DWidget *parent)
     setLayout(hLayout);
 
     connect(m_confirmButton, &ToolButton::clicked, pMainwindow, &MainWindow::confirm);
-    connect(m_closeButton, &ToolButton::clicked, pMainwindow, &MainWindow::exitApp);
+    connect(m_closeButton, &ToolButton::clicked, pMainwindow, &MainWindow::exitApp);    
     connect(m_subTool, &SubToolWidget::keyBoardButtonClicked, pMainwindow, &MainWindow::changeKeyBoardShowEvent);
     connect(m_subTool, &SubToolWidget::mouseBoardButtonClicked, pMainwindow, &MainWindow::changeMouseShowEvent);
+
+    // TODO:treeland适配
+    connect(m_subTool, &SubToolWidget::shotOptionMenuShown, pMainwindow, &MainWindow::handleOptionMenuShown);
+
     QMetaObject::Connection connectHandle =  connect(m_subTool, SIGNAL(cameraActionChecked(bool)), pMainwindow, SLOT(changeCameraSelectEvent(bool)));
     if (!connectHandle) {
         qDebug() <<__FUNCTION__ << __LINE__ <<  "Connect failed!";
@@ -127,7 +131,7 @@ void ToolBarWidget::setRecordLaunchFromMain(const unsigned int funType)
 
 void ToolBarWidget::setRecordButtonDisable()
 {
-    m_subTool->setRecordButtonDisable();
+   // m_subTool->setRecordButtonDisable();
 }
 
 void ToolBarWidget::setVideoInitFromMain()
@@ -163,12 +167,19 @@ void ToolBarWidget::setExpand(bool expand, QString shapeType)
     update();
 }
 */
+
+QRect ToolBarWidget::getShotOptionRect(){
+   return m_subTool->getShotOptionRect();
+}
+
 ToolBarWidget::~ToolBarWidget() {}
 
 
 ToolBar::ToolBar(DWidget *parent)
     : DLabel(parent)
 {
+    //setAttribute(Qt::WA_TranslucentBackground);
+    //setWindowFlags(Qt::FramelessWindowHint | Qt::Tool | Qt::WindowStaysOnTopHint);
     m_toolbarWidget = nullptr;
 }
 
@@ -177,20 +188,24 @@ void ToolBar::paintEvent(QPaintEvent *e)
     DLabel::paintEvent(e);
 }
 
+#if (QT_VERSION_MAJOR == 5)
 void ToolBar::enterEvent(QEvent *e)
 {
-//    qApp->setOverrideCursor(Qt::ArrowCursor);
+    //    qApp->setOverrideCursor(Qt::ArrowCursor);
     QApplication::setOverrideCursor(Qt::OpenHandCursor);
     DLabel::enterEvent(e);
 }
+#elif (QT_VERSION_MAJOR == 6)
+void ToolBar::enterEvent(QEnterEvent *e)
+{
+    //    qApp->setOverrideCursor(Qt::ArrowCursor);
+    QApplication::setOverrideCursor(Qt::OpenHandCursor);
+    DLabel::enterEvent(e);
+}
+#endif
 
 bool ToolBar::eventFilter(QObject *obj, QEvent *event)
 {
-    if (event->type() == QEvent::ApplicationPaletteChange || event->type() == QEvent::PaletteChange) {
-        qDebug() << obj;
-        qDebug() << "--------------";
-    }
-
     return DLabel::eventFilter(obj, event);
 }
 
@@ -275,6 +290,8 @@ void ToolBar::showAt(QPoint pos)
 
     move(pos.x(), pos.y());
 }
+
+
 void ToolBar::currentFunctionMode(QString shapeType)
 {
     DPalette pa;
@@ -286,8 +303,8 @@ void ToolBar::initToolBar(MainWindow *pmainWindow)
 {
     m_pMainWindow = pmainWindow;
     setFixedHeight(TOOLBAR_HEIGHT);
-    m_toolbarWidget = new ToolBarWidget(pmainWindow, this);
 
+    m_toolbarWidget = new ToolBarWidget(pmainWindow, this);
     QHBoxLayout *vLayout = new QHBoxLayout();
     vLayout->setSizeConstraint(QLayout::SetFixedSize);
     vLayout->setContentsMargins(0, 0, 0, 0);
@@ -300,6 +317,16 @@ void ToolBar::initToolBar(MainWindow *pmainWindow)
     connect(m_toolbarWidget, &ToolBarWidget::changeFunctionSignal, this, &ToolBar::currentFunctionMode);
 }
 
+void ToolBar::showWidget(){
+    if(m_toolbarWidget)
+        m_toolbarWidget->show();
+}
+
+void ToolBar::hideWidget(){
+    if(m_toolbarWidget)
+        m_toolbarWidget->hide();
+}
+
 void ToolBar::setRecordButtonDisable()
 {
     m_toolbarWidget->setRecordButtonDisable();
@@ -330,6 +357,10 @@ void ToolBar::setCameraDeviceEnable(bool status)
 {
     m_toolbarWidget->setCameraDeviceEnable(status);
 }
+
+QRect ToolBar::getShotOptionRect(){
+   return m_toolbarWidget->getShotOptionRect();
+}
 ToolBar::~ToolBar()
 {
 }
