@@ -23,6 +23,17 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <translation>Qeyd aparılır</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Yazmaq</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ekran şəkli</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -93,13 +104,21 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Scrollshot</source>
         <translation>Sürüşdürmə</translation>
     </message>
+    <message>
+        <source>Pin Screenshots</source>
+        <translation>Ekran şəkllərini sancaqlayın</translation>
+    </message>
+    <message>
+        <source>deepin-screen-recorder</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <source>Open Folder</source>
         <translation>Qovluğu açın</translation>
     </message>
     <message>
-        <source>Pin Screenshots</source>
-        <translation>Ekran şəkllərini sancaqlayın</translation>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -124,6 +143,28 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <translation>Ekran şəkllərini sancaqlayın</translation>
     </message>
 </context>
+<context>
+    <name>QuickPanelWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ekran şəkli</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Yazmaq</translation>
+    </message>
+</context>
+<context>
+    <name>RecordIconWidget</name>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ekran şəkli</translation>
+    </message>
+    <message>
+        <source>Recording</source>
+        <translation>Qeyd aparılır</translation>
+    </message>
+</context>
 <context>
     <name>RecordProcess</name>
     <message>
@@ -306,6 +347,10 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Display shortcuts</source>
         <translation>Ekran qısayolları</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Səs</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Düymə basılması</translation>
@@ -326,6 +371,10 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Start/Recording</source>
         <translation>Başlatmaq/Yazılma</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Siçan</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Alətlər</translation>
@@ -342,38 +391,33 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Pin screenshots</source>
         <translation>Ekran şəkllərini sancaqlayın</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>Sürüşdürməni başladın</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>OCR-i başladın</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Sürüşdürməni başladın</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Ox</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Səs</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Siçan</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
-    <message>
-        <source>Screen Capture</source>
-        <translation>Ekran şəkli çəkmək</translation>
-    </message>
     <message>
         <source>Screenshot</source>
         <translation>Ekran şəkli</translation>
     </message>
 </context>
+<context>
+    <name>ShotStartRecordPlugin</name>
+    <message>
+        <source>Record</source>
+        <translation>Yazmaq</translation>
+    </message>
+</context>
 <context>
     <name>ShotToolWidget</name>
     <message>
@@ -407,15 +451,48 @@ Düz xətt çəkmək üçün Shift düyməsini basıb saxlayın</translation>
         <translation>Yazı ölçüsünü təyin edin (Bunu üçün sürüşdürün)</translation>
     </message>
 </context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Toxunub sürüşdürməklə
+yazılacaq sahəni seçin</translation>
+    </message>
+</context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Mikrofon</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Düymə basılması göstərilsin (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Seçimlər</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Düymə basılmasını gizlətmək (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Düymə basılması göstərilsin (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Kameranı açın (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Kameranı söndürün (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Ekran şəkli</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Ayarlar</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Ayarlar (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -429,6 +506,14 @@ Düz xətt çəkmək üçün Shift düyməsini basıb saxlayın</translation>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -454,128 +539,36 @@ Düz xətt çəkmək üçün Shift düyməsini basıb saxlayın</translation>
         <translation>30 fps</translation>
     </message>
     <message>
-        <source>Save to</source>
-        <translation>Belə saxlayın</translation>
+        <source>Sound</source>
+        <translation>Səs</translation>
     </message>
     <message>
-        <source>Desktop</source>
-        <translation>İş Masası</translation>
+        <source>Microphone</source>
+        <translation>Mikrofon</translation>
     </message>
     <message>
-        <source>Pictures</source>
-        <translation>Şəkillər</translation>
+        <source>System audio</source>
+        <translation>Sistem səsi</translation>
     </message>
     <message>
-        <source>Folder</source>
-        <translation>Qovluq</translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
-    <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
-    </message>
-    <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
-    </message>
-    <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Mübadilə yaddaşı</translation>
+        <source>Options</source>
+        <translation>Seçimlər</translation>
     </message>
     <message>
         <source>Show pointer</source>
         <translation>Göstərici görünsün</translation>
     </message>
     <message>
-        <source>Extract Text</source>
-        <translation>Mətni çıxarın</translation>
+        <source>Show click</source>
+        <translation>Klikləmə görünsün</translation>
     </message>
     <message>
-        <source>Show keystroke (K)</source>
-        <translation>Düymə basılması göstərilsin (K)</translation>
+        <source>Save to</source>
+        <translation>Belə saxlayın</translation>
     </message>
     <message>
-        <source>Settings</source>
-        <translation>Ayarlar</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Ayarlar (F3)</translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation>Bulanıq (B)</translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation>Mətn (M)</translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation>Sürüşdürmə (Alt+İ)</translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation>Mətni çıxarın (Alt+O)</translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Geriyə (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Ekran şəkli</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation>Ekran şəklini sancaqla (Alt+P)</translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>Yazmaq</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation>Qələm (P)</translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation>Kameranı açın (C)</translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation>Çərçivə effektləri</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>Heç biri</translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Kameranı söndürün (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Düymə basılmasını gizlətmək (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Düymə basılması göstərilsin (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
+        <source>Desktop</source>
+        <translation>İş Masası</translation>
     </message>
     <message>
         <source>Videos</source>
@@ -605,29 +598,97 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Ox (X)
 Üfüqi və ya şaquli ox çəkmək üçün Shift düyməsini basıb saxlayın</translation>
     </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>Qələm (P)</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>Bulanıq (B)</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>Mətn (M)</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>Sürüşdürmə (Alt+İ)</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>Mətni çıxarın (Alt+O)</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>Ekran şəklini sancaqla (Alt+P)</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Geriyə (Ctrl+Z)</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Yazmaq</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>Mübadilə yaddaşı</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Şəkillər</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Qovluq</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Saxlamaq üçün bir yol təyin edin</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Saxlamaq üçün yolu dəyişin</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
+    </message>
+    <message>
+        <source>Border Effects</source>
+        <translation>Çərçivə effektləri</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Heç biri</translation>
+    </message>
     <message>
         <source>Shadow</source>
-        <translation type="unfinished"/>
+        <translation>Kölgə</translation>
     </message>
     <message>
         <source>Border</source>
-        <translation type="unfinished"/>
+        <translation>Şərçivə</translation>
     </message>
     <message>
         <source>Device</source>
-        <translation type="unfinished"/>
+        <translation>Cihaz</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Səs</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"/>
+        <source>Extract Text</source>
+        <translation>Mətni çıxarın</translation>
     </message>
 </context>
 <context>
@@ -659,4 +720,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Çıxış</translation>
     </message>
 </context>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Yeni ekran qeydi</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
