@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="bo">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -22,7 +20,18 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>བརྙན་ཕབ།</translation>
+    </message>
+</context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>བརྙན་ཕབ།</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>བརྙན་བཤུས།</translation>
     </message>
 </context>
 <context>
@@ -95,17 +104,21 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation>འགུལ་ནས་ཡོལ་པར་བླངས།</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
-        <translation type="unfinished">སྦྱར་རིས།</translation>
+        <translation>སྦྱར་རིས།</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,18 +147,18 @@ or press the shortcut again to stop recording</source>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">བརྙན་བཤུས།</translation>
+        <translation>བརྙན་བཤུས།</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">བརྙན་ཕབ།</translation>
+        <translation>བརྙན་ཕབ།</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">བརྙན་བཤུས།</translation>
+        <translation>བརྙན་བཤུས།</translation>
     </message>
     <message>
         <source>Recording</source>
@@ -172,7 +185,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Open Folder</source>
-        <translation type="unfinished"></translation>
+        <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
     </message>
 </context>
 <context>
@@ -334,6 +347,10 @@ or press the shortcut again to stop recording</source>
         <source>Display shortcuts</source>
         <translation>མྱུར་མཐེབ་གསལ་བ།</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>སྒྲ་འབེབས།</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>མཐེབ་གནོན།</translation>
@@ -354,6 +371,10 @@ or press the shortcut again to stop recording</source>
         <source>Start/Recording</source>
         <translation>བརྙན་འབེབས་དང་འགོ་སློང་།</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>ཕབ་བཟོའི་ཙི་གུ།</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>ཡོ་བྱད།</translation>
@@ -371,24 +392,16 @@ or press the shortcut again to stop recording</source>
         <translation>སྦྱར་རིས།</translation>
     </message>
     <message>
-        <source>Start scrollshot</source>
-        <translation type="unfinished"></translation>
+        <source>Start OCR</source>
+        <translation>པར་རིས་དབྱེ་འབྱེད་མགྱོགས་མྱུར་འགོ་སློང་།</translation>
     </message>
     <message>
-        <source>Start OCR</source>
-        <translation type="unfinished"></translation>
+        <source>Start scrollshot</source>
+        <translation>འགུལ་ནས་བཪྙན་ལེན་འགོ་སློང་།</translation>
     </message>
     <message>
         <source>Arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation type="unfinished">ཕབ་བཟོའི་ཙི་གུ།</translation>
+        <translation>མདའ་རྟགས།</translation>
     </message>
 </context>
 <context>
@@ -402,7 +415,7 @@ or press the shortcut again to stop recording</source>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">བརྙན་ཕབ།</translation>
+        <translation>བརྙན་ཕབ།</translation>
     </message>
 </context>
 <context>
@@ -410,40 +423,75 @@ or press the shortcut again to stop recording</source>
     <message>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
+        <translation>གྲུ་བཞི་ནར་མོ།
+Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་ཐུབ།</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
+        <translation>འཇོང་དབྱིབས་
+Shiftམནན་ནས་སྒོར་དབྱིབས་འབྲི་ཐུབ། </translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation type="unfinished"></translation>
+        <translation>ཕག་ཏོ་
+Shiftམནན་ནས་དྲང་ཐིག་འབྲི་ཐུབ།</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>རབ་རིབ་ཡོད་ཚད་སྙོམ་སྒྲིག་（ཙི་གུའི་འགྲིལ་འཁོར།）</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>ཕག་ཏོ་ཆེ་ཆུང་སྙོམ་སྒྲིག་（ཙི་གུའི་འགྲིལ་འཁོར།）</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>ཡི་གེ་ཆེ་ཆུང་སྙོམ་སྒྲིག་（ཙི་གུའི་འགྲིལ་འཁོར།）</translation>
+    </message>
+</context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>སྐད་དུང་།</translation>
+        <source>Show keystroke (K)</source>
+        <translation>མཐེབ་གཅུས་Kམངོན་པ།</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>གདམ་ག</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>མཐེབ་གཅུས་ཡིབ་པ་ (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>མཐེབ་གཅུས་མངོན་པ་ (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>བཪྙན་མིག་ཁ་ཕྱེ།(C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>བཪྙན་མིག་ཁ་རྒྱོབ་ (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>བརྙན་བཤུས།</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>སྒྲིག་བཀོད།</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>སྒྲིག་བཀོད་(F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -457,6 +505,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>ལྡེབ་གྲངས།</translation>
@@ -481,6 +537,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>སྒྲ་འབེབས།</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>སྐད་དུང་།</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>མ་ལག་སྒྲ་ཟློས།</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>གདམ་ག</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>འོད་རྟགས་གསལ་བ།</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>གནོན་པ་གསལ་བ།</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>དུ་ཉར་བ།</translation>
@@ -489,6 +569,70 @@ Press and hold Shift to draw a straight line</source>
         <source>Desktop</source>
         <translation>ཅོག་ངོས།</translation>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation>བཪྙན་ཟློས།</translation>
+    </message>
+    <message>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>གྲུ་བཞི་ནར་མོ། (R)
+Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་ཐུབ།</translation>
+    </message>
+    <message>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>འཇོང་དབྱིབས་ (O)
+Shiftམནན་ནས་སྒོར་དབྱིབས་འབྲི་ཐུབ། </translation>
+    </message>
+    <message>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>ཕག་ཏོ་ (L)
+Shiftམནན་ནས་དྲང་ཐིག་འབྲི་ཐུབ།</translation>
+    </message>
+    <message>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>མདའ་རྩེ་ (X)
+Shiftམནན་ནས་ཐད་དཔྱང་དང་ཆུ་སྙོམས་ཀྱི་དྲང་ཐིག་འབྲི་ཐུབ།</translation>
+    </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>པིར་སྨྱུག་ (P)</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>རབ་རིབ། (B)</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>ཡི་གེ། (T)</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>འགྲིལ་ནས་པར་ལེན་ (Alt+I）</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>ཡི་གེ་ངོས་འཛིན་ Alt+O</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>སྦྱར་རིས་ (Alt+P）</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>ཕྱིར་འཐེན་ Ctrl+Z</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>བརྙན་ཕབ།</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>དྲས་སྦྱར་པང་།</translation>
+    </message>
     <message>
         <source>Pictures</source>
         <translation>པར་རིས།</translation>
@@ -497,6 +641,14 @@ Press and hold Shift to draw a straight line</source>
         <source>Folder</source>
         <translation>དམིགས་བཙུགས་ས་གནས།</translation>
     </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>ཉར་སྐབས་གནས་ས་སྒྲིག་འགོད་བྱེད་པ། </translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>ཉར་སྐབས་གནས་ས་གསར་སྒྱུར་བྱེད་པ།</translation>
+    </message>
     <message>
         <source>Format</source>
         <translation>རྣམ་བཞག་ </translation>
@@ -514,163 +666,39 @@ Press and hold Shift to draw a straight line</source>
         <translation>BMP</translation>
     </message>
     <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
+        <source>Border Effects</source>
+        <translation>མཐའ་སྒྲོམ་ཕན་ནུས།</translation>
     </message>
     <message>
-        <source>Clipboard</source>
-        <translation>དྲས་སྦྱར་པང་།</translation>
+        <source>None</source>
+        <translation>མཐའ་སྒྲོམ་མེད་པ།</translation>
     </message>
     <message>
-        <source>Show pointer</source>
-        <translation>འོད་རྟགས་གསལ་བ།</translation>
+        <source>Shadow</source>
+        <translation>བརྙན་སྟོན།</translation>
+    </message>
+    <message>
+        <source>Border</source>
+        <translation>ཕྱིའི་མཐའ་སྒྲོམ།</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>བཟོ་ལྟ།</translation>
     </message>
     <message>
         <source>Extract Text</source>
         <translation>ཡི་གེ་ངོས་འཛིན།</translation>
     </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>སྒྲིག་བཀོད།</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>བརྙན་བཤུས།</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>བརྙན་ཕབ།</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Shadow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Border</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Device</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
     <message>
         <source>Close (Esc)</source>
-        <translation type="unfinished"></translation>
+        <translation>ཁ་རྒྱག་(Esc)</translation>
     </message>
     <message>
         <source>OK (Enter)</source>
-        <translation type="unfinished"></translation>
+        <translation>གཏན་འཁེལ་ (Enter)</translation>
     </message>
 </context>
 <context>
@@ -691,4 +719,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>ཕྱིར་འཐེན།</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
+</TS>
\ No newline at end of file
