@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="fi">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -18,18 +16,29 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     <name>IconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation>Ruudunkaappaus</translation>
+        <translation>Kaappaus</translation>
     </message>
     <message>
         <source>Recording</source>
         <translation>Tallennus</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Tallenna</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Kaappaus</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
         <source>Screen Capture</source>
-        <translation>Ruudunkaappaus</translation>
+        <translation>Kaappaus</translation>
     </message>
     <message>
         <source>Save failed. Please save it in your home directory.</source>
@@ -85,7 +94,7 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     </message>
     <message>
         <source>Screenshot</source>
-        <translation>Ruudunkaappaus</translation>
+        <translation>Kaappaus</translation>
     </message>
     <message>
         <source>Screenshot failed.</source>
@@ -95,17 +104,21 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Scrollshot</source>
         <translation>Vierittävä kaappaus</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>Avaa kansio</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>Kiinnitä kaappaukset</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Avaa kansio</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Ruudunkaappaus</translation>
+        <translation>Kaappaus</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Tallenna</translation>
+        <translation>Tallenna</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Ruudunkaappaus</translation>
+        <translation>Kaappaus</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Tallennus</translation>
+        <translation>Tallentaa</translation>
     </message>
 </context>
 <context>
@@ -179,7 +192,7 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     <name>Screenshot</name>
     <message>
         <source>Screen Capture will start in %1 seconds</source>
-        <translation>Ruudunkaappaus alkaa %1 sekunnissa</translation>
+        <translation>Kaappaus alkaa %1 sekunnissa</translation>
     </message>
 </context>
 <context>
@@ -334,6 +347,10 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Display shortcuts</source>
         <translation>Näytä kuvakkeet</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Ääni</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Näppäimistö</translation>
@@ -354,6 +371,10 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Start/Recording</source>
         <translation>Aloita tallennus</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Hiiri</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Työkalut</translation>
@@ -368,41 +389,33 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     </message>
     <message>
         <source>Pin screenshots</source>
-        <translation>Kiinnitä kuvakaappaukset</translation>
-    </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>Aloita vierivä kaappaus</translation>
+        <translation>Kiinnitä kaappaukset</translation>
     </message>
     <message>
         <source>Start OCR</source>
         <translation>Aloita OCR</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Aloita vierivä kaappaus</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Nuoli</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Ääni</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Hiiri</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
     <message>
         <source>Screenshot</source>
-        <translation>Ruudunkaappaus</translation>
+        <translation>Kaappaus</translation>
     </message>
 </context>
 <context>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Tallenna</translation>
+        <translation>Tallenna</translation>
     </message>
 </context>
 <context>
@@ -410,40 +423,76 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     <message>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
+        <translation>Suorakulmio
+Piirrä neliö pitämällä Shift-painettuna</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Ellipsi
+Piirrä ympyrä pitämällä Shift-painettuna</translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation type="unfinished"></translation>
+        <translation>Sivellin
+Vedä suora viiva pitämällä Shift-painettuna</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Muuta läpikuultavuutta (vieritä säätääksesi)</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Muuta siveltimen kokoa (vieritä säätääksesi)</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Muuta tekstin kokoa (vieritä säätääksesi)</translation>
+    </message>
+</context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Napsauta tai vedä
+valitse tallennettava alue</translation>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Mikrofoni</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Näytä näppäimistö (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Valinnat</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Piilota näppäimistö (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Näytä näppäimistö (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Kytke kamera (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Sammuta kamera (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Kaappaus</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Asetukset</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Asetukset (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -457,6 +506,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -481,6 +538,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Ääni</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Mikrofoni</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>Järjestelmän ääni</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Valinnat</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Näytä osoitin</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Näytä painallus</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Tallenna nimellä</translation>
@@ -490,56 +571,36 @@ Press and hold Shift to draw a straight line</source>
         <translation>Työpöytä</translation>
     </message>
     <message>
-        <source>Pictures</source>
-        <translation>Kuvat</translation>
+        <source>Videos</source>
+        <translation>Videot</translation>
     </message>
     <message>
-        <source>Folder</source>
-        <translation>Kansio</translation>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>Suorakulmio (R)
+Piirrä neliö pitämällä Shift-painettuna</translation>
     </message>
     <message>
-        <source>Format</source>
-        <translation>Muoto</translation>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>Ellipsi (O).
+Piirrä ympyrä pitämällä Shift-painettuna</translation>
     </message>
     <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>Viiva (L)
+Vedä suora pysty- tai vaakaviiva pitämällä Shift-painettuna</translation>
     </message>
     <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>Nuoli (X)
+Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
     </message>
     <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Leikepöydälle</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>Näytä osoitin</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>Poimi tekstiä</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>Näytä näppäimistö (K)</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Asetukset</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Asetukset (F3)</translation>
+        <source>Pencil (P)</source>
+        <translation>Kynä (P)</translation>
     </message>
     <message>
         <source>Blur (B)</source>
@@ -557,29 +618,53 @@ Press and hold Shift to draw a straight line</source>
         <source>Extract text (Alt+O）</source>
         <translation>Poimi tekstiä (Alt+O）</translation>
     </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Kumoa (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Ruudunkaappaus</translation>
-    </message>
     <message>
         <source>Pin screenshots (Alt+P）</source>
         <translation>Kiinnitä kaappaukset (Alt+P）</translation>
     </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Kumoa (Ctrl+Z)</translation>
+    </message>
     <message>
         <source>Record</source>
         <translation>Tallenna</translation>
     </message>
     <message>
-        <source>Pencil (P)</source>
-        <translation>Kynä (P)</translation>
+        <source>Clipboard</source>
+        <translation>Leikepöydälle</translation>
     </message>
     <message>
-        <source>Turn on camera (C)</source>
-        <translation>Kytke kamera (C)</translation>
+        <source>Pictures</source>
+        <translation>Kuvat</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Kansio</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Aseta tallennuspolku</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Muuta polkua tallentaessa</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Muoto</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
     </message>
     <message>
         <source>Border Effects</source>
@@ -589,77 +674,21 @@ Press and hold Shift to draw a straight line</source>
         <source>None</source>
         <translation>Ei mitään</translation>
     </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Sammuta kamera (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Piilota näppäimistö (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Näytä näppäimistö (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation>Videot</translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Shadow</source>
-        <translation type="unfinished"></translation>
+        <translation>Varjo</translation>
     </message>
     <message>
         <source>Border</source>
-        <translation type="unfinished"></translation>
+        <translation>Reunus</translation>
     </message>
     <message>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Laite</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Ääni</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>Poimi tekstiä</translation>
     </message>
 </context>
 <context>
@@ -691,4 +720,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Poistu</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Uusi äänitys</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
