@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ms">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Rakaman</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Rakam</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Tangkap Layar</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -95,17 +104,21 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <source>Scrollshot</source>
         <translation>Tangkap tatal</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>Cemat Tangkap Layar</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Buka Folder</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Tangkap Layar</translation>
+        <translation>Tangkap Layar</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Rakam</translation>
+        <translation>Rakam</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Tangkap Layar</translation>
+        <translation>Tangkap Layar</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Rakaman</translation>
+        <translation>Merakam</translation>
     </message>
 </context>
 <context>
@@ -172,7 +185,7 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
     </message>
     <message>
         <source>Open Folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Buka Folder</translation>
     </message>
 </context>
 <context>
@@ -334,6 +347,10 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <source>Display shortcuts</source>
         <translation>Papar pintasan</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Bunyi</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Ketukan kekunci</translation>
@@ -354,6 +371,10 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <source>Start/Recording</source>
         <translation>Mula/Rakaman</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Tetikus</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Alatan</translation>
@@ -371,25 +392,17 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Cemat tangkap layar</translation>
     </message>
     <message>
-        <source>Start scrollshot</source>
-        <translation type="unfinished"></translation>
+        <source>Start OCR</source>
+        <translation>Mula OCR</translation>
     </message>
     <message>
-        <source>Start OCR</source>
-        <translation type="unfinished"></translation>
+        <source>Start scrollshot</source>
+        <translation>Mula tangkap tatal</translation>
     </message>
     <message>
         <source>Arrow</source>
         <translation>Anak Panah</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Bunyi</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Tetikus</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Rakam</translation>
+        <translation>Rakam</translation>
     </message>
 </context>
 <context>
@@ -410,40 +423,76 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
     <message>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
+        <translation>Segi Empat
+Tekan dan tahan kekunci Shift untuk membentuk sebuah petak</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Elips
+Tekan dan tahan kekunci Shift untuk membentuk sebuah bulatan</translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation type="unfinished"></translation>
+        <translation>Berus
+Tekan dan tahan kekunci Shift untuk membentuk satu garisan lurus</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Laras kekuatan kabur (Tatal untuk melarasnya)</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Laras saiz berus (Tatal untuk melarasnya)</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Laras saiz teks (Tatal untuk melarasnya)</translation>
+    </message>
+</context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Klik atau seret untuk
+pilih kawasan rakaman</translation>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Mikrofon</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Tunjuk ketukan kekunci (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Pilihan</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Sembunyi Ketukan Kekunci (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Tunjuk Ketukan Kekunci (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Hidupkan kamera (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Matikan kamera (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Tangkap Layar</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Tetapan</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Tetapan (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -457,6 +506,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -481,6 +538,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Bunyi</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Mikrofon</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>Audio sistem</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Pilihan</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Tunjuk penuding</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Tunjuk klik</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Simpan ke</translation>
@@ -490,56 +571,36 @@ Press and hold Shift to draw a straight line</source>
         <translation>Atas Meja</translation>
     </message>
     <message>
-        <source>Pictures</source>
-        <translation>Gambar</translation>
+        <source>Videos</source>
+        <translation>Video</translation>
     </message>
     <message>
-        <source>Folder</source>
-        <translation>Folder</translation>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>Segiempat (R)
+Tekan dan tahan kekunci Shift untuk melukis sebuah segiempat</translation>
     </message>
     <message>
-        <source>Format</source>
-        <translation>Format</translation>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>Elips (O)
+Tekan dan tahan kekunci Shift untuk melukis sebuah bulatan</translation>
     </message>
     <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>Garisan (L)
+Tekan dan tahan kekunci Shift untuk melukis garisan menegak atau mengufuk</translation>
     </message>
     <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>Anak panah (X)
+Tekan dan tahan kekunci Shift untuk melukis anak panah menegak atau mengufuk</translation>
     </message>
     <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Papan keratan</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>Tunjuk penuding</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>Ekstrak Teks</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>Tunjuk ketukan kekunci (K)</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Tetapan</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Tetapan (F3)</translation>
+        <source>Pencil (P)</source>
+        <translation>Pensel (P)</translation>
     </message>
     <message>
         <source>Blur (B)</source>
@@ -557,109 +618,77 @@ Press and hold Shift to draw a straight line</source>
         <source>Extract text (Alt+O）</source>
         <translation>Ekstrak teks (Alt+O)</translation>
     </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Buat asal (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Tangkap Layar</translation>
-    </message>
     <message>
         <source>Pin screenshots (Alt+P）</source>
         <translation>Cemat tangkap layar (Alt+P)</translation>
     </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Buat asal (Ctrl+Z)</translation>
+    </message>
     <message>
         <source>Record</source>
         <translation>Rakam</translation>
     </message>
     <message>
-        <source>Pencil (P)</source>
-        <translation>Pensel (P)</translation>
+        <source>Clipboard</source>
+        <translation>Papan keratan</translation>
     </message>
     <message>
-        <source>Turn on camera (C)</source>
-        <translation type="unfinished"></translation>
+        <source>Pictures</source>
+        <translation>Gambar</translation>
     </message>
     <message>
-        <source>Border Effects</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Shadow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Border</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Device</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound</source>
-        <translation>Bunyi</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
+        <source>Folder</source>
+        <translation>Folder</translation>
     </message>
     <message>
         <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
+        <translation>Tetapkan laluan ketika simpan</translation>
     </message>
     <message>
         <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <translation>Ubah laluan ketika simpan</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
+    </message>
+    <message>
+        <source>Border Effects</source>
+        <translation>Kesan Sempadan</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Tiada</translation>
+    </message>
+    <message>
+        <source>Shadow</source>
+        <translation>Bayang</translation>
+    </message>
+    <message>
+        <source>Border</source>
+        <translation>Sempadan</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>Peranti</translation>
+    </message>
+    <message>
+        <source>Extract Text</source>
+        <translation>Ekstrak Teks</translation>
     </message>
 </context>
 <context>
@@ -691,4 +720,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Keluar</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Rakaman baharu</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
