@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,11 +23,22 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Opname</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Opnemen</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Schermfoto</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
         <source>Screen Capture</source>
-        <translation>Schermfoto</translation>
+        <translation>Scherm vastleggen</translation>
     </message>
     <message>
         <source>Save failed. Please save it in your home directory.</source>
@@ -95,17 +104,21 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Scrollshot</source>
         <translation>Scrollende schermfoto</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>Map openen</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>Schermfoto&apos;s vastmaken</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Map openen</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Schermfoto</translation>
+        <translation>Schermfoto</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Opnemen</translation>
+        <translation>Opnemen</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Schermfoto</translation>
+        <translation>Schermfoto</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Opname</translation>
+        <translation>Opname</translation>
     </message>
 </context>
 <context>
@@ -334,6 +347,10 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Display shortcuts</source>
         <translation>Sneltoetsen tonen</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Geluid</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Toetsaanslag</translation>
@@ -354,6 +371,10 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Start/Recording</source>
         <translation>Opname starten</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Cursor</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Gereedschap</translation>
@@ -370,26 +391,18 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <source>Pin screenshots</source>
         <translation>Schermfoto&apos;s vastmaken</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>Scrollende schermfoto maken</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>Ocr maken</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Scrollende schermfoto maken</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Pijl</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Geluid</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Cursor</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Opnemen</translation>
+        <translation>Opnemen</translation>
     </message>
 </context>
 <context>
@@ -438,15 +451,48 @@ Houd Shift ingedrukt om een rechte lijn te trekken</translation>
         <translation>Tekstgrootte aanpassen (met scrolwiel)</translation>
     </message>
 </context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Klik of sleep om
+het opnamegebied te kiezen</translation>
+    </message>
+</context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Microfoon</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Toetsaanslagen tonen (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Opties</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Toetsaanslagen verbergen (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Toetsaanslagen tonen (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Camera aanzetten (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Camera uitzetten (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Schermfoto</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Instellingen</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Instellingen (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -460,6 +506,14 @@ Houd Shift ingedrukt om een rechte lijn te trekken</translation>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -485,128 +539,36 @@ Houd Shift ingedrukt om een rechte lijn te trekken</translation>
         <translation>30 fps</translation>
     </message>
     <message>
-        <source>Save to</source>
-        <translation>Opslaan op/in</translation>
+        <source>Sound</source>
+        <translation>Geluid</translation>
     </message>
     <message>
-        <source>Desktop</source>
-        <translation>Bureaublad</translation>
+        <source>Microphone</source>
+        <translation>Microfoon</translation>
     </message>
     <message>
-        <source>Pictures</source>
-        <translation>Afbeeldingen</translation>
+        <source>System audio</source>
+        <translation>Systeemgeluid</translation>
     </message>
     <message>
-        <source>Folder</source>
-        <translation>Andere map</translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation>Formaat:</translation>
-    </message>
-    <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
-    </message>
-    <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
-    </message>
-    <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Klembord</translation>
+        <source>Options</source>
+        <translation>Opties</translation>
     </message>
     <message>
         <source>Show pointer</source>
         <translation>Cursor vastleggen</translation>
     </message>
     <message>
-        <source>Extract Text</source>
-        <translation>Tekst extraheren</translation>
+        <source>Show click</source>
+        <translation>Muisklikken tonen</translation>
     </message>
     <message>
-        <source>Show keystroke (K)</source>
-        <translation>Toetsaanslagen tonen (K)</translation>
+        <source>Save to</source>
+        <translation>Opslaan op/in</translation>
     </message>
     <message>
-        <source>Settings</source>
-        <translation>Instellingen</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Instellingen (F3)</translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation>Vervagen (B)</translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation>Tekst (T)</translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation>Scrollende schermfoto (Alt+I)</translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation>Tekst extraheren (Alt+O)</translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Ongedaan maken (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Schermfoto</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation>Schermfoto&apos;s vastmaken (Alt+P)</translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>Opnemen</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation>Potlood (P)</translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation>Camera aanzetten (C)</translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation>Randeffecten</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>Geen</translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Camera uitzetten (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Toetsaanslagen verbergen (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Toetsaanslagen tonen (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
+        <source>Desktop</source>
+        <translation>Bureaublad</translation>
     </message>
     <message>
         <source>Videos</source>
@@ -636,6 +598,82 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Pijl (X)
 Houd Shift ingedrukt om een verticale of horizontale pijl te tekenen</translation>
     </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>Potlood (P)</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>Vervagen (B)</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>Tekst (T)</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>Scrollende schermfoto (Alt+I)</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>Tekst extraheren (Alt+O)</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>Schermfoto&apos;s vastmaken (Alt+P)</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Ongedaan maken (Ctrl+Z)</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Opnemen</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>Klembord</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Afbeeldingen</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Andere map</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Locatie kiezen na klikken op opslaan</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Locatie wijzigen na klikken op opslaan</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formaat:</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
+    </message>
+    <message>
+        <source>Border Effects</source>
+        <translation>Randeffecten</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Geen</translation>
+    </message>
     <message>
         <source>Shadow</source>
         <translation>Schaduw</translation>
@@ -649,24 +687,8 @@ Houd Shift ingedrukt om een verticale of horizontale pijl te tekenen</translatio
         <translation>Apparaat</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Geluid</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>Tekst extraheren</translation>
     </message>
 </context>
 <context>
@@ -698,4 +720,11 @@ Houd Shift ingedrukt om een verticale of horizontale pijl te tekenen</translatio
         <translation>Afsluiten</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Opname maken</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
