@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <translation>Nagrywanie</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Nagrywanie</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Zrzut ekranu</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -33,7 +42,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Save failed. Please save it in your home directory.</source>
-        <translation>Zapisywanie nie powiodło się. Proszę zapisać plik w swoim katalogu domowym.</translation>
+        <translation>Zapisywanie nie powiodło się. Zapisz w swoim katalogu domowym.</translation>
     </message>
     <message>
         <source>View</source>
@@ -89,23 +98,27 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Screenshot failed.</source>
-        <translation>Niepowodzenie zrzutu ekranu</translation>
+        <translation>Zrzut ekranu nie powiódł się.</translation>
     </message>
     <message>
         <source>Scrollshot</source>
         <translation>Pionowy zrzut ekranu</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>Otwórz katalog</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>Przypnij zrzuty ekranu</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Otwórz folder</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -120,7 +133,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Exit</source>
-        <translation>Wyjście</translation>
+        <translation>Wyjdź</translation>
     </message>
 </context>
 <context>
@@ -134,22 +147,22 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Zrzut ekranu</translation>
+        <translation>Zrzut ekranu</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Nagrywanie</translation>
+        <translation>Nagrywanie</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Zrzut ekranu</translation>
+        <translation>Zrzut ekranu</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">Nagrywanie</translation>
+        <translation>Nagrywanie</translation>
     </message>
 </context>
 <context>
@@ -172,7 +185,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Open Folder</source>
-        <translation>Otwórz katalog</translation>
+        <translation>Otwórz folder</translation>
     </message>
 </context>
 <context>
@@ -190,11 +203,11 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Failed to take a continuous screenshot.</source>
-        <translation>Niepowodzenie ciągłego zrzutu ekranu</translation>
+        <translation>Nie udało się utworzyć pionowego zrzutu ekranu</translation>
     </message>
     <message>
         <source>Reached the bottom of the scroll area</source>
-        <translation>Dotarto do samego końca obszaru przewijania</translation>
+        <translation>Dotarto do końca obszaru przewijania</translation>
     </message>
     <message>
         <source>Reached the maximum length</source>
@@ -206,7 +219,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
-        <translation>Przewijaj kółkiem myszki lub klikaj, aby zrobić pionowy zrzut ekranu</translation>
+        <translation>Przewijaj kółkiem myszy lub klikaj, aby zrobić pionowy zrzut ekranu</translation>
     </message>
     <message>
         <source>Slow down the scrolling speed</source>
@@ -214,14 +227,14 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Invalid area, click to </source>
-        <translation>Obszar nieprawidłowy, kliknij aby </translation>
+        <translation>Nieprawidłowy obszar, kliknij aby </translation>
     </message>
 </context>
 <context>
     <name>ShapesWidget</name>
     <message>
         <source>Input text here</source>
-        <translation>Wprowadź tutaj tekst</translation>
+        <translation>Wprowadź tekst tutaj</translation>
     </message>
 </context>
 <context>
@@ -232,7 +245,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Exit/Save</source>
-        <translation>Wyjście/Zapisz</translation>
+        <translation>Wyjdź/Zapisz</translation>
     </message>
     <message>
         <source>Size Adjustment</source>
@@ -260,7 +273,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     </message>
     <message>
         <source>Exit</source>
-        <translation>Wyjście</translation>
+        <translation>Wyjdź</translation>
     </message>
     <message>
         <source>Save</source>
@@ -334,6 +347,10 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <source>Display shortcuts</source>
         <translation>Wyświetl skróty</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Dźwięk</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>Naciśnięcie klawisza</translation>
@@ -354,6 +371,10 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <source>Start/Recording</source>
         <translation>Rozpocznij/Nagrywanie</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Mysz</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Narzędzia</translation>
@@ -370,26 +391,18 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <source>Pin screenshots</source>
         <translation>Przypnij zrzuty ekranu</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>Rozpocznij pionowy zrzut ekranu</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>Rozpocznij OCR</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Rozpocznij pionowy zrzut ekranu</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>Strzałka</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>Dźwięk</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>Myszka</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Nagrywanie</translation>
+        <translation>Nagrywanie</translation>
     </message>
 </context>
 <context>
@@ -438,15 +451,48 @@ Przytrzymaj Shift, aby rysować prostą linię</translation>
         <translation>Dostosuj rozmiar tekstu (Przewijaj, aby dostosować)</translation>
     </message>
 </context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Kliknij lub przeciągnij do zaznaczonego
+obszaru, aby zacząć nagrywać</translation>
+    </message>
+</context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Mikrofon</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Pokaż naciśnięcie klawisza (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Opcje</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Ukryj naciśnięcie klawisza (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Pokaż naciśnięcie klawisza (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Włącz kamerę (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Wyłącz kamerę (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Zrzut ekranu</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Ustawienia</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Ustawienia (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -460,6 +506,14 @@ Przytrzymaj Shift, aby rysować prostą linię</translation>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -484,6 +538,30 @@ Przytrzymaj Shift, aby rysować prostą linię</translation>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Dźwięk</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Mikrofon</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>Audio systemowe</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Opcje</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Pokaż kursor</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Pokaż kliknięcie</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Zapisz do</translation>
@@ -492,122 +570,6 @@ Przytrzymaj Shift, aby rysować prostą linię</translation>
         <source>Desktop</source>
         <translation>Pulpit</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Zdjęcia</translation>
-    </message>
-    <message>
-        <source>Folder</source>
-        <translation>Katalog</translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation>Format</translation>
-    </message>
-    <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
-    </message>
-    <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
-    </message>
-    <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>Schowek</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>Pokaż wskaźnik</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>Wydobądź tekst</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>Pokazuj naciśnięcie klawisza (K)</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Ustawienia</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>Ustawienia (F3)</translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation>Rozmycie (B)</translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation>Tekst (T)</translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation>Pionowy zrzut ekranu (Alt+I)</translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation>Wydobądź tekst (Alt+O)</translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>Cofnij (Ctrl+Z)</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Zrzut ekranu</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation>Przypnij zrzuty ekranu (Alt+P)</translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>Nagrywanie</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation>Ołówek (P)</translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation>Włącz kamerę (C)</translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation>Efekty obramówki</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>Brak</translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>Wyłącz kamerę (C)</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>Ukrywaj naciśnięcie klawisza (K)</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>Pokazuj naciśnięcie klawisza (K)</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
     <message>
         <source>Videos</source>
         <translation>Filmy</translation>
@@ -636,6 +598,82 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Strzałka (X)
 Przytrzymaj Shift, aby rysować pionową lub poziomą strzałkę</translation>
     </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>Ołówek (P)</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>Rozmycie (B)</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>Tekst (T)</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>Pionowy zrzut ekranu (Alt+I)</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>Wydobądź tekst (Alt+O)</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>Przypnij zrzuty ekranu (Alt+P)</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Cofnij (Ctrl+Z)</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Nagrywanie</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>Schowek</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>Zdjęcia</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Folder</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Ustaw ścieżkę zapisu</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Zmień ścieżkę zapisu</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
+    </message>
+    <message>
+        <source>Border Effects</source>
+        <translation>Efekty obramówki</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Brak</translation>
+    </message>
     <message>
         <source>Shadow</source>
         <translation>Cień</translation>
@@ -649,24 +687,8 @@ Przytrzymaj Shift, aby rysować pionową lub poziomą strzałkę</translation>
         <translation>Urządzenie</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>Dźwięk</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>Wydobądź tekst</translation>
     </message>
 </context>
 <context>
@@ -695,7 +717,14 @@ Przytrzymaj Shift, aby rysować pionową lub poziomą strzałkę</translation>
     </message>
     <message>
         <source>Exit</source>
-        <translation>Wyjście</translation>
+        <translation>Wyjdź</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Nowe nagranie</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
