@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pt_BR">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -22,7 +20,18 @@ clique no ícone da bandeja ou use o atalho</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Gravando</translation>
+    </message>
+</context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>Gravar</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Capturar</translation>
     </message>
 </context>
 <context>
@@ -95,17 +104,21 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Scrollshot</source>
         <translation>Tela de rolagem</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
-        <translation type="unfinished"></translation>
+        <translation>Fixar capturas de tela</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Abrir pasta</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -127,29 +140,29 @@ clique no ícone da bandeja ou use o atalho</translation>
     <name>QObject</name>
     <message>
         <source>Pin Screenshots</source>
-        <translation type="unfinished"></translation>
+        <translation>Fixar capturas de tela</translation>
     </message>
 </context>
 <context>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Capturar</translation>
+        <translation>Captura de tela</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Gravar</translation>
+        <translation>Gravar</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">Capturar</translation>
+        <translation>Captura de tela</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Gravando</translation>
     </message>
 </context>
 <context>
@@ -172,7 +185,7 @@ clique no ícone da bandeja ou use o atalho</translation>
     </message>
     <message>
         <source>Open Folder</source>
-        <translation type="unfinished"></translation>
+        <translation>Abrir pasta</translation>
     </message>
 </context>
 <context>
@@ -334,9 +347,13 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Display shortcuts</source>
         <translation>Exibir atalhos</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Som</translation>
+    </message>
     <message>
         <source>Keystroke</source>
-        <translation>Tecla</translation>
+        <translation>Pressionamento de tecla</translation>
     </message>
     <message>
         <source>Webcam</source>
@@ -354,6 +371,10 @@ clique no ícone da bandeja ou use o atalho</translation>
         <source>Start/Recording</source>
         <translation>Iniciar / Gravação</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>Mouse</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>Ferramentas</translation>
@@ -371,24 +392,16 @@ clique no ícone da bandeja ou use o atalho</translation>
         <translation>Fixar capturas de tela</translation>
     </message>
     <message>
-        <source>Start scrollshot</source>
-        <translation type="unfinished"></translation>
+        <source>Start OCR</source>
+        <translation>Iniciar OCR</translation>
     </message>
     <message>
-        <source>Start OCR</source>
-        <translation type="unfinished"></translation>
+        <source>Start scrollshot</source>
+        <translation>Iniciar tela de rolagem</translation>
     </message>
     <message>
         <source>Arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation type="unfinished">Mouse</translation>
+        <translation>Seta</translation>
     </message>
 </context>
 <context>
@@ -402,7 +415,7 @@ clique no ícone da bandeja ou use o atalho</translation>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">Gravar</translation>
+        <translation>Gravar</translation>
     </message>
 </context>
 <context>
@@ -410,40 +423,76 @@ clique no ícone da bandeja ou use o atalho</translation>
     <message>
         <source>Rectangle
 Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
+        <translation>Retângulo
+Mantenha pressionada a tecla Shift para desenhar um quadrado</translation>
     </message>
     <message>
         <source>Ellipse
 Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Elipse
+Mantenha pressionada a tecla Shift para desenhar um círculo</translation>
     </message>
     <message>
         <source>Brush
 Press and hold Shift to draw a straight line</source>
-        <translation type="unfinished"></translation>
+        <translation>Pincel
+Mantenha pressionada a tecla Shift para desenhar uma linha reta</translation>
     </message>
     <message>
         <source>Adjust blur strength (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajustar a intensidade do desfoque (Role para ajustá-la)</translation>
     </message>
     <message>
         <source>Adjust brush size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajustar o tamanho do pincel (Role para ajustá-lo)</translation>
     </message>
     <message>
         <source>Adjust text size (Scroll to adjust it)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajustar o tamanho do texto (Role para ajustá-lo)</translation>
+    </message>
+</context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>Clique ou arraste para
+selecione a área para gravar</translation>
     </message>
 </context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>Microfone</translation>
+        <source>Show keystroke (K)</source>
+        <translation>Exibir pressionamento de tecla (K)</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>Opções</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>Ocultar tecla (K)</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>Exibir tecla (K)</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>Ligar câmera (C)</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>Desligue câmera (C)</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>Capturar</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Configurações</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>Configurações (F3)</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -457,6 +506,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>FPS:</translation>
@@ -481,6 +538,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>Som</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>Microfone</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>Áudio do sistema</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>Opções</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>Exibir cursor</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>Exibir clique</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>Salvar em</translation>
@@ -489,6 +570,70 @@ Press and hold Shift to draw a straight line</source>
         <source>Desktop</source>
         <translation>Área de Trabalho</translation>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation>Vídeos</translation>
+    </message>
+    <message>
+        <source>Rectangle (R)
+Press and hold Shift to draw a square</source>
+        <translation>Retângulo (R)
+Mantenha pressionada a tecla Shift para desenhar um quadrado</translation>
+    </message>
+    <message>
+        <source>Ellipse (O)
+Press and hold Shift to draw a circle</source>
+        <translation>Elipse (O)
+Mantenha pressionada a tecla Shift para desenhar um círculo</translation>
+    </message>
+    <message>
+        <source>Line (L)
+Press and hold Shift to draw a vertical or horizontal line</source>
+        <translation>Linha (L)
+Mantenha pressionada a tecla Shift para desenhar uma linha vertical ou horizontal</translation>
+    </message>
+    <message>
+        <source>Arrow (X)
+Press and hold Shift to draw a vertical or horizontal arrow</source>
+        <translation>Seta (X)
+Mantenha pressionada a tecla Shift para desenhar uma seta vertical ou horizontal</translation>
+    </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>Lápis (P)</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>Desfocar (B)</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>Texto (T)</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>Tela de rolagem (Alt+I)</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>Extrair texto (Alt+O)</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>Fixar capturas de tela (Alt+P)</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>Desfazer (Ctrl+Z)</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>Gravar</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>Área de Transferência</translation>
+    </message>
     <message>
         <source>Pictures</source>
         <translation>Imagens</translation>
@@ -497,6 +642,14 @@ Press and hold Shift to draw a straight line</source>
         <source>Folder</source>
         <translation>Pasta</translation>
     </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Definir caminho para salvar</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Alterar caminho ao salvar</translation>
+    </message>
     <message>
         <source>Format</source>
         <translation>Formato</translation>
@@ -514,163 +667,39 @@ Press and hold Shift to draw a straight line</source>
         <translation>BMP</translation>
     </message>
     <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
+        <source>Border Effects</source>
+        <translation>Efeitos de borda</translation>
     </message>
     <message>
-        <source>Clipboard</source>
-        <translation>Área de Transferência</translation>
+        <source>None</source>
+        <translation>Nenhum</translation>
     </message>
     <message>
-        <source>Show pointer</source>
-        <translation>Exibir cursor</translation>
+        <source>Shadow</source>
+        <translation>Sombra</translation>
+    </message>
+    <message>
+        <source>Border</source>
+        <translation>Borda</translation>
+    </message>
+    <message>
+        <source>Device</source>
+        <translation>Dispositivo</translation>
     </message>
     <message>
         <source>Extract Text</source>
         <translation>Extrair texto</translation>
     </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>Configurações</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>Capturar</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>Gravar</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Videos</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rectangle (R)
-Press and hold Shift to draw a square</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Ellipse (O)
-Press and hold Shift to draw a circle</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Line (L)
-Press and hold Shift to draw a vertical or horizontal line</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Arrow (X)
-Press and hold Shift to draw a vertical or horizontal arrow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Shadow</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Border</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Device</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Sound</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>ToolBarWidget</name>
     <message>
         <source>Close (Esc)</source>
-        <translation type="unfinished"></translation>
+        <translation>Fechar (Esc)</translation>
     </message>
     <message>
         <source>OK (Enter)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ok (Enter)</translation>
     </message>
 </context>
 <context>
@@ -691,4 +720,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>Sair</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>Nova gravação</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
