@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ or press the shortcut again to stop recording</source>
         <translation>录屏</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>录屏</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>截图</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -95,10 +104,6 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation>滚动截图</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>打开文件夹</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>贴图</translation>
@@ -107,6 +112,14 @@ or press the shortcut again to stop recording</source>
         <source>deepin-screen-recorder</source>
         <translation>截图录屏</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>打开文件夹</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation>截图完成，文件已复制到剪贴板</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -134,22 +147,22 @@ or press the shortcut again to stop recording</source>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">截图</translation>
+        <translation>截图</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">录屏</translation>
+        <translation>录屏</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">截图</translation>
+        <translation>截图</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">录屏</translation>
+        <translation>录屏</translation>
     </message>
 </context>
 <context>
@@ -252,7 +265,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Delay screenshot</source>
-        <translation>延时截图</translation>
+        <translation>延时5秒截屏</translation>
     </message>
     <message>
         <source>Full screenshot</source>
@@ -334,6 +347,10 @@ or press the shortcut again to stop recording</source>
         <source>Display shortcuts</source>
         <translation>显示快捷键</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>录音</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>按键</translation>
@@ -354,6 +371,10 @@ or press the shortcut again to stop recording</source>
         <source>Start/Recording</source>
         <translation>启动/录屏</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>录制鼠标</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>工具</translation>
@@ -370,26 +391,18 @@ or press the shortcut again to stop recording</source>
         <source>Pin screenshots</source>
         <translation>贴图</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>启动滚动截图</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>快速启动图文识别</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>启动滚动截图</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>箭头</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>声音</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>录制鼠标</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ or press the shortcut again to stop recording</source>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">录屏</translation>
+        <translation>录屏</translation>
     </message>
 </context>
 <context>
@@ -438,15 +451,47 @@ Press and hold Shift to draw a straight line</source>
         <translation>调整文字大小（鼠标滚轮）</translation>
     </message>
 </context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>麦克风</translation>
+        <source>Show keystroke (K)</source>
+        <translation>显示按键 K</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>选项</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>隐藏按键 K</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>显示按键 K</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>开启摄像头 C</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>关闭摄像头 C</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>截图</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>设置</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>设置 F3</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -460,6 +505,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>帧数：</translation>
@@ -484,6 +537,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>声音</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>麦克风</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>系统音频</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>选项</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>显示光标</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>显示鼠标点击</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>保存到</translation>
@@ -492,122 +569,6 @@ Press and hold Shift to draw a straight line</source>
         <source>Desktop</source>
         <translation>桌面</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>图片</translation>
-    </message>
-    <message>
-        <source>Folder</source>
-        <translation>指定位置</translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation>格式</translation>
-    </message>
-    <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
-    </message>
-    <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
-    </message>
-    <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>剪贴板</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>显示鼠标光标</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>识别文字</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>显示按键 K</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>设置</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>设置 F3</translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation>模糊 B</translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation>文字 T</translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation>滚动截图 Alt+I</translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation>识别文字 Alt+O</translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>撤销 Ctrl+Z</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>截图</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation>贴图 Alt+P</translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>录屏</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation>画笔 P</translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation>开启摄像头 C</translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation>边框效果</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>无边框</translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>关闭摄像头 C</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>隐藏按键 K</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>显示按键 K</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
     <message>
         <source>Videos</source>
         <translation>视频</translation>
@@ -636,6 +597,82 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>箭头（X）
 按住Shift可画垂直和水平箭头</translation>
     </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>画笔 P</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>模糊 B</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>文字 T</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>滚动截图 Alt+I</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>识别文字 Alt+O</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>贴图 Alt+P</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>撤销 Ctrl+Z</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>录屏</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>剪贴板</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>图片</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>指定位置</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>保存时设置位置</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>保存时更新位置</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>格式</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
+    </message>
+    <message>
+        <source>Border Effects</source>
+        <translation>边框效果</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>无边框</translation>
+    </message>
     <message>
         <source>Shadow</source>
         <translation>投影</translation>
@@ -649,24 +686,8 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>样机</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>声音</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation>系统音频</translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation>显示鼠标点击</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>保存时设置位置</translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation>保存时更新位置</translation>
+        <source>Extract Text</source>
+        <translation>识别文字</translation>
     </message>
 </context>
 <context>
@@ -698,4 +719,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>退出</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>新录音</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
