@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_HK">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
 <context>
     <name>CountdownTooltip</name>
     <message>
@@ -25,6 +23,17 @@ or press the shortcut again to stop recording</source>
         <translation>錄屏</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Record</source>
+        <translation>錄屏</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>截圖</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -37,7 +46,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>View</source>
-        <translation>查看</translation>
+        <translation>檢視</translation>
     </message>
     <message>
         <source>Screenshot finished</source>
@@ -57,7 +66,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>select-area</source>
-        <translation>選擇區域</translation>
+        <translation>選取範圍</translation>
     </message>
     <message>
         <source>Save</source>
@@ -95,17 +104,21 @@ or press the shortcut again to stop recording</source>
         <source>Scrollshot</source>
         <translation>滾動截圖</translation>
     </message>
-    <message>
-        <source>Open Folder</source>
-        <translation>打開文件夾</translation>
-    </message>
     <message>
         <source>Pin Screenshots</source>
         <translation>貼圖</translation>
     </message>
     <message>
         <source>deepin-screen-recorder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>打開文件夾</translation>
+    </message>
+    <message>
+        <source>Screenshot finished and copy to clipboard</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -134,29 +147,29 @@ or press the shortcut again to stop recording</source>
     <name>QuickPanelWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">截圖</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Record</source>
-        <translation type="unfinished">錄屏</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
     <name>RecordIconWidget</name>
     <message>
         <source>Screenshot</source>
-        <translation type="unfinished">截圖</translation>
+        <translation>截圖</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished">錄屏</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
     <name>RecordProcess</name>
     <message>
         <source>View</source>
-        <translation>查看</translation>
+        <translation>檢視</translation>
     </message>
     <message>
         <source>Recording finished</source>
@@ -164,7 +177,7 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Saved to %1</source>
-        <translation>文件已保存到%1</translation>
+        <translation>圖片已保存到%1</translation>
     </message>
     <message>
         <source>Record</source>
@@ -228,7 +241,7 @@ or press the shortcut again to stop recording</source>
     <name>Shortcut</name>
     <message>
         <source>Start/Screenshot</source>
-        <translation>啟動/截圖 </translation>
+        <translation>啟動/截圖</translation>
     </message>
     <message>
         <source>Exit/Save</source>
@@ -252,11 +265,11 @@ or press the shortcut again to stop recording</source>
     </message>
     <message>
         <source>Delay screenshot</source>
-        <translation>延時截圖</translation>
+        <translation>延時5秒截屏</translation>
     </message>
     <message>
         <source>Full screenshot</source>
-        <translation>截取全螢幕</translation>
+        <translation>截取全屏</translation>
     </message>
     <message>
         <source>Exit</source>
@@ -334,6 +347,10 @@ or press the shortcut again to stop recording</source>
         <source>Display shortcuts</source>
         <translation>顯示快捷鍵</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>錄音</translation>
+    </message>
     <message>
         <source>Keystroke</source>
         <translation>按鍵</translation>
@@ -354,6 +371,10 @@ or press the shortcut again to stop recording</source>
         <source>Start/Recording</source>
         <translation>啟動/錄屏</translation>
     </message>
+    <message>
+        <source>Mouse</source>
+        <translation>錄製鼠標</translation>
+    </message>
     <message>
         <source>Tools</source>
         <translation>工具</translation>
@@ -370,26 +391,18 @@ or press the shortcut again to stop recording</source>
         <source>Pin screenshots</source>
         <translation>貼圖</translation>
     </message>
-    <message>
-        <source>Start scrollshot</source>
-        <translation>啟動滾動截圖</translation>
-    </message>
     <message>
         <source>Start OCR</source>
         <translation>快速啟動圖文識別</translation>
     </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>啟動滾動截圖</translation>
+    </message>
     <message>
         <source>Arrow</source>
         <translation>箭頭</translation>
     </message>
-    <message>
-        <source>Sound</source>
-        <translation>聲音</translation>
-    </message>
-    <message>
-        <source>Mouse</source>
-        <translation>錄製鼠標</translation>
-    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -402,7 +415,7 @@ or press the shortcut again to stop recording</source>
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-        <translation type="unfinished">錄屏</translation>
+        <translation>錄屏</translation>
     </message>
 </context>
 <context>
@@ -438,15 +451,48 @@ Press and hold Shift to draw a straight line</source>
         <translation>調整文字大小（鼠標滾輪）</translation>
     </message>
 </context>
+<context>
+    <name>StartTooltip</name>
+    <message>
+        <source>Click or drag to
+select the area to record</source>
+        <translation>點擊或拖曳以
+選取要錄影的範圍 </translation>
+    </message>
+</context>
 <context>
     <name>SubToolWidget</name>
     <message>
-        <source>Microphone</source>
-        <translation>麥克風</translation>
+        <source>Show keystroke (K)</source>
+        <translation>顯示按鍵 K</translation>
     </message>
     <message>
-        <source>Options</source>
-        <translation>選項</translation>
+        <source>Hide Keystroke (K)</source>
+        <translation>隱藏按鍵 K</translation>
+    </message>
+    <message>
+        <source>Show Keystroke (K)</source>
+        <translation>顯示按鍵 K</translation>
+    </message>
+    <message>
+        <source>Turn on camera (C)</source>
+        <translation>開啟鏡頭 C</translation>
+    </message>
+    <message>
+        <source>Turn off camera (C)</source>
+        <translation>關閉鏡頭 C</translation>
+    </message>
+    <message>
+        <source>Screenshot</source>
+        <translation>截圖</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>設置</translation>
+    </message>
+    <message>
+        <source>Settings (F3)</source>
+        <translation>設置 F3</translation>
     </message>
     <message>
         <source>Format:</source>
@@ -460,6 +506,14 @@ Press and hold Shift to draw a straight line</source>
         <source>MP4</source>
         <translation>MP4</translation>
     </message>
+    <message>
+        <source>MKV</source>
+        <translation>MKV</translation>
+    </message>
+    <message>
+        <source>webm</source>
+        <translation>webm</translation>
+    </message>
     <message>
         <source>FPS:</source>
         <translation>幀數：</translation>
@@ -484,6 +538,30 @@ Press and hold Shift to draw a straight line</source>
         <source>30 fps</source>
         <translation>30 fps</translation>
     </message>
+    <message>
+        <source>Sound</source>
+        <translation>聲音</translation>
+    </message>
+    <message>
+        <source>Microphone</source>
+        <translation>麥克風</translation>
+    </message>
+    <message>
+        <source>System audio</source>
+        <translation>系統音頻</translation>
+    </message>
+    <message>
+        <source>Options</source>
+        <translation>選項</translation>
+    </message>
+    <message>
+        <source>Show pointer</source>
+        <translation>顯示光標</translation>
+    </message>
+    <message>
+        <source>Show click</source>
+        <translation>顯示鼠標點擊</translation>
+    </message>
     <message>
         <source>Save to</source>
         <translation>保存到</translation>
@@ -492,122 +570,6 @@ Press and hold Shift to draw a straight line</source>
         <source>Desktop</source>
         <translation>桌面</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>圖片</translation>
-    </message>
-    <message>
-        <source>Folder</source>
-        <translation>指定位置</translation>
-    </message>
-    <message>
-        <source>Format</source>
-        <translation>格式</translation>
-    </message>
-    <message>
-        <source>PNG</source>
-        <translation>PNG</translation>
-    </message>
-    <message>
-        <source>JPG</source>
-        <translation>JPG</translation>
-    </message>
-    <message>
-        <source>BMP</source>
-        <translation>BMP</translation>
-    </message>
-    <message>
-        <source>MKV</source>
-        <translation>MKV</translation>
-    </message>
-    <message>
-        <source>Clipboard</source>
-        <translation>剪貼板</translation>
-    </message>
-    <message>
-        <source>Show pointer</source>
-        <translation>顯示鼠標光標</translation>
-    </message>
-    <message>
-        <source>Extract Text</source>
-        <translation>識別文字</translation>
-    </message>
-    <message>
-        <source>Show keystroke (K)</source>
-        <translation>顯示按鍵 K</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <translation>設置</translation>
-    </message>
-    <message>
-        <source>Settings (F3)</source>
-        <translation>設置 F3</translation>
-    </message>
-    <message>
-        <source>Blur (B)</source>
-        <translation>模糊 B</translation>
-    </message>
-    <message>
-        <source>Text (T)</source>
-        <translation>文字 T</translation>
-    </message>
-    <message>
-        <source>Scrollshot (Alt+I）</source>
-        <translation>滾動截圖 Alt+I</translation>
-    </message>
-    <message>
-        <source>Extract text (Alt+O）</source>
-        <translation>識別文字 Alt+O</translation>
-    </message>
-    <message>
-        <source>Undo (Ctrl+Z)</source>
-        <translation>撤銷 Ctrl+Z</translation>
-    </message>
-    <message>
-        <source>Screenshot</source>
-        <translation>截圖</translation>
-    </message>
-    <message>
-        <source>Pin screenshots (Alt+P）</source>
-        <translation>貼圖 Alt+P</translation>
-    </message>
-    <message>
-        <source>Record</source>
-        <translation>錄屏</translation>
-    </message>
-    <message>
-        <source>Pencil (P)</source>
-        <translation>畫筆 P</translation>
-    </message>
-    <message>
-        <source>Turn on camera (C)</source>
-        <translation>開啟鏡頭 C</translation>
-    </message>
-    <message>
-        <source>Border Effects</source>
-        <translation>邊框效果</translation>
-    </message>
-    <message>
-        <source>None</source>
-        <translation>無邊框</translation>
-    </message>
-    <message>
-        <source>Turn off camera (C)</source>
-        <translation>關閉鏡頭 C</translation>
-    </message>
-    <message>
-        <source>Hide Keystroke (K)</source>
-        <translation>隱藏按鍵 K</translation>
-    </message>
-    <message>
-        <source>Show Keystroke (K)</source>
-        <translation>顯示按鍵 K</translation>
-    </message>
-    <message>
-        <source>webm</source>
-        <translation>webm</translation>
-    </message>
     <message>
         <source>Videos</source>
         <translation>影片</translation>
@@ -636,6 +598,82 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>箭頭（X）
 按住Shift可畫垂直和水平箭頭</translation>
     </message>
+    <message>
+        <source>Pencil (P)</source>
+        <translation>畫筆 P</translation>
+    </message>
+    <message>
+        <source>Blur (B)</source>
+        <translation>模糊 B</translation>
+    </message>
+    <message>
+        <source>Text (T)</source>
+        <translation>文字 T</translation>
+    </message>
+    <message>
+        <source>Scrollshot (Alt+I）</source>
+        <translation>滾動截圖 Alt+I</translation>
+    </message>
+    <message>
+        <source>Extract text (Alt+O）</source>
+        <translation>識別文字 Alt+O</translation>
+    </message>
+    <message>
+        <source>Pin screenshots (Alt+P）</source>
+        <translation>貼圖 Alt+P</translation>
+    </message>
+    <message>
+        <source>Undo (Ctrl+Z)</source>
+        <translation>撤銷 Ctrl+Z</translation>
+    </message>
+    <message>
+        <source>Record</source>
+        <translation>錄屏</translation>
+    </message>
+    <message>
+        <source>Clipboard</source>
+        <translation>剪貼板</translation>
+    </message>
+    <message>
+        <source>Pictures</source>
+        <translation>圖片</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>指定位置</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>保存時設置位置</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>保存時更新位置</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>格式</translation>
+    </message>
+    <message>
+        <source>PNG</source>
+        <translation>PNG</translation>
+    </message>
+    <message>
+        <source>JPG</source>
+        <translation>JPG</translation>
+    </message>
+    <message>
+        <source>BMP</source>
+        <translation>BMP</translation>
+    </message>
+    <message>
+        <source>Border Effects</source>
+        <translation>邊框效果</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>無邊框</translation>
+    </message>
     <message>
         <source>Shadow</source>
         <translation>投影</translation>
@@ -649,24 +687,8 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>樣機</translation>
     </message>
     <message>
-        <source>Sound</source>
-        <translation>聲音</translation>
-    </message>
-    <message>
-        <source>System audio</source>
-        <translation>系統音頻</translation>
-    </message>
-    <message>
-        <source>Show click</source>
-        <translation>顯示鼠標點擊</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Change the path on save</source>
-        <translation type="unfinished"></translation>
+        <source>Extract Text</source>
+        <translation>識別文字</translation>
     </message>
 </context>
 <context>
@@ -684,7 +706,7 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
     <name>TopTips</name>
     <message>
         <source> Adjust the recording area within %1*%2 to get better video effect</source>
-        <translation> 調整錄製區域範圍在%1*%2以內，影片效果更佳</translation>
+        <translation> 調整錄製區域範圍在%1*%2以內，視頻效果更佳</translation>
     </message>
 </context>
 <context>
@@ -698,4 +720,11 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <translation>退出</translation>
     </message>
 </context>
-</TS>
+<context>
+    <name>VoiceRecordProcess</name>
+    <message>
+        <source>New recording</source>
+        <translation>新錄音</translation>
+    </message>
+</context>
+</TS>
\ No newline at end of file
